{% docs action_type %}
This macro maps action type ID to the action type.
{% enddocs %}

{% docs filter_out_blocked_users %}
This macro takes in the name of the table and column that contain GitLab user ids. This macro creates the SQL filter for filtering out users blocked by GitLab.

The SQL filter returned does not include a `WHERE`, `AND`, or `OR` so it can flexibly be used as any part of the `WHERE` clause.  For example, to filter out blocked users from a table named `users` with a column named `user_id`, the dbt model would look like

```
{% raw %}
SELECT *
FROM users
WHERE {{ filter_out_blocked_users('users', 'user_id') }}
{% endraw %}
```

This macro should be used downstream of source models, in models where activities of blocked users may introduce noise to metrics.  For example, this macro is used in `gitlab_dotcom_usage_data_events` to only keep events generated from legitimate use.

{% enddocs %}

{% docs filter_out_active_users %}
This macro takes in the name of the table and column that contain GitLab user ids. This macro creates the SQL filter for filtering out users with an active account status on GitLab.

The SQL filter returned does not include a `WHERE`, `AND`, or `OR` so it can flexibly be used as any part of the `WHERE` clause.  For example, to filter out active users from a table named `users` with a column named `user_id`, the dbt model would look like

```
{% raw %}
SELECT *
FROM users
WHERE {{ filter_out_active_users('users', 'user_id') }}
{% endraw %}
```

This macro should be used downstream of source models, in models where we are isolating the activities of blocked or deactivated users from active users.  For example, this macro is used in `gitlab_dotcom_usage_data_events` to only keep events generated by blocked and deactivated users.

{% enddocs %}

{% docs get_internal_parent_namespaces %}
Returns a list of all the internal GitLab parent namespaces, enclosed in round brackets. This is useful for filtering an analysis down to external users only.

{% enddocs %}

{% docs map_state_id %}
This macro maps state_ids to english state names (opened, closed, etc).
{% enddocs %}


{% docs resource_event_action_type %}
This macro maps action type ID to the action type for the `resource_label_events` table.
{% enddocs %}


{% docs transform_clusters_applications %}
This macro takes in a ref (base model) and performs some joins to make an xf model out of the base model. This is used for all the `clusters_applications_*` tables as they all have the same structure and columns.
{% enddocs %}


{% docs user_role_mapping %}
This macro maps "role" values (integers) from the user table into their respective string values.

For example, user_role=0 maps to the 'Software Developer' role.

{% enddocs %}

{% docs dedupe_source %}
This macro speed up data deduplication for the `PREP.GITLAB_DOTCOM` layer. This is a follow-up on `RAW.TAP_POSTGRES` schema data.
For instance, calling the macro with the command:

{% raw %}
```sql
{{ dedupe_source(source_table='workspaces') }}
```
{% endraw %}

will be translated as:
```sql
SELECT *

FROM RAW.tap_postgres.gitlab_db_workspaces

QUALIFY ROW_NUMBER() OVER (PARTITION BY id ORDER BY updated_at DESC) = 1
```
and this is handy as the files for data deduplication as smaller and unified.

{% enddocs %}

{% docs visibility_level_name %}

Maps visibility level ids to their corresponding names (Public, Internal, Private).

{% enddocs %}