WITH final AS (

    SELECT
        marketo_lead_id AS dim_marketo_person_id,
        {{ dbt_utils.generate_surrogate_key(['sfdc_contact_id', 'sfdc_lead_id']) }} AS dim_crm_person_id,
        email_hash,
        sfdc_lead_id,
        sfdc_contact_id,
        job_title AS title,
        country,
        sfdc_type AS sfdc_record_type,
        is_email_bounced,
        email_bounced_date AS marketo_email_bounced_date,
        is_unsubscribed,
        is_opt_in,
        is_pql_marketo,
        is_paid_tier_marketo,
        is_ptpt_contact_marketo,
        is_ptp_contact_marketo,
        is_impacted_by_user_limit_marketo,
        is_currently_in_trial_marketo,
        trial_start_date_marketo,
        trial_end_date_marketo,
        priority AS marketo_priority,
        urgency AS marketo_urgency,
        relative_score AS marketo_relative_person_score,
        relative_urgency AS marketo_relative_urgency,
        lead_score AS marketo_person_score,
        demographic_score AS marketo_demographic_score,
        lead_source AS marketo_lead_source,
        lead_status AS marketo_lead_status,
        acquisition_program_id,
        mkto_acquisition_date AS marketo_acquisition_date,
        behavior_score AS marketo_behavior_score,
        opt_in_date AS marketo_opt_in_date,
        active_user_c AS is_active_user,
        created_date_time_c AS marketo_created_date_time,
        newsletter_segment_c_lead AS marketo_newsletter_segment,
        subscribe_webcast_c AS is_subscribed_webcast,
        subscribe_live_events_c AS is_subscribed_live_events,
        gdpr_compliant_c AS is_gdpr_compliant,
        sign_up_date,
        opt_out_date,
        email_suspended AS is_email_suspended,
        email_suspended_at AS email_suspended_date,
        email_suspended_cause,
        initial_start_date_c AS initial_start_date,
        original_source_type,
        registration_source_type,
        products_purchased_c AS products_purchased,
        migration_services_requested AS has_requested_migration_services,
        license_user_count_c AS license_user_count,
        git_labcom_user_id_c AS gitlabdotcom_user_id,
        implementation_service_requested AS has_requested_implementation_services,
        ratingscale AS marketo_rating_scale,
        specialized_trainings_requested AS has_requested_specialized_trainings,
        account_id_18_c AS dim_crm_account_id,
        core_user_c AS is_core_user,
        health_c AS marketo_health_score,
        tech_stack_c AS tech_stack,
        plan_active_c AS is_active_plan,
        engagio_pipeline_predict_score_c AS engagio_pipeline_predict_score,
        secure_active_c AS is_secure_active,
        marketing_suspended AS is_marketing_suspended,
        original_source_info,
        infer_infer_score_c AS infer_score,
        customer_health_score_date_c AS customer_health_score_date,
        email_opt_out_c AS is_email_opt_out,
        events_segment AS is_events_segment,
        double_opt_in_date,
        black_listed AS is_black_listed,
        do_not_route_c AS is_do_not_route,
        double_opt_in AS is_double_opt_in,
        education_requested AS has_requested_education,
        data_quality_score_c AS data_quality_score,
        mkto_2_lead_score_c AS marketo_lead_score_2,
        person_type AS marketo_person_type,
        email_bounced_reason,
        x_30_day_opt_out_c AS is_30_day_opt_out,
        marketing_comm_opt_out_c AS is_marketing_comm_opt_out,
        using_ce_c AS is_using_ce,
        do_not_contact_c AS is_do_not_contact,
        email_invalid AS is_invalid_email,
        high_priority_c AS is_high_priority,
        unsubscribe_all_marketing AS is_unsubscribe_all_marketing,
        compliance_segment_value,
        region_c AS marketo_person_region,
        region_c_account AS marketo_account_region,
        preferred_language_c AS preferred_language,
        account_tier_c AS marketo_account_tier,
        account_tier_notes_c AS marketo_account_tier_notes,
        COALESCE(abm_tier_c,abm_tier_c_lead) AS marketo_abm_tier,
        account_demographics_upa_country_c AS account_demographics_upa_country,
        account_demographics_upa_country_name_c AS account_demographics_upa_country_name,
        product_category_c AS product_category
    FROM {{ ref('marketo_lead_source') }}

)

{{ dbt_audit(
    cte_ref="final",
    created_by="@rkohnke",
    updated_by="@rkohnke",
    created_date="2024-03-25",
    updated_date="2024-03-25"
) }}