{{ config(
    tags=["mnpi_exception"],
    materialized="incremental",
    unique_key="mau_id"
) }}


WITH date_details AS (
  
    SELECT *
    FROM {{ ref('date_details') }}
  
)

, gitlab_dotcom_usage_data_events AS (
  
    SELECT *
    FROM {{ ref('gitlab_dotcom_usage_data_events') }}
    {% if is_incremental() %}

      WHERE DATE_TRUNC('month', event_created_at) >= (SELECT DATEADD('days', -1, MAX(smau_month)) FROM {{this}})

    {% endif %}
      
)

, gitlab_subscriptions AS (

    SELECT *
    FROM {{ ref('gitlab_dotcom_gitlab_subscriptions_snapshots_namespace_id_base') }}
)

, plans AS (

    SELECT *
    FROM {{ ref('gitlab_dotcom_plans') }}

)

SELECT 
  -- primary key
  {{ dbt_utils.generate_surrogate_key(['gitlab_dotcom_usage_data_events.namespace_id',
                              'user_id', 
                              'event_name', 
                              'DATEADD(month, -1, date_day)']) }}                      AS mau_id,
  DATEADD('month', -1, date_day)                                                         AS smau_month,
  
  -- ids 
  gitlab_dotcom_usage_data_events.user_id,
  gitlab_dotcom_usage_data_events.namespace_id,
  
  
  -- user dimensions
  CASE
    WHEN gitlab_subscriptions.is_trial
      THEN 'trial'
    ELSE COALESCE(gitlab_subscriptions.plan_id, 34)::VARCHAR
  END                                                                                    AS plan_id_at_smau_month_end,
  CASE
    WHEN gitlab_subscriptions.is_trial
      THEN 'trial'
    ELSE COALESCE(plans.plan_name, 'free')
  END                                                                                    AS plan_name_at_smau_month_end,
  
  -- event data
  event_name,
  stage_name,
  is_representative_of_stage,
  
  --metadata
  -- aggregating because user_created_at and namespace_created_at can be impacted by late arriving dimensions
  MAX(DATEDIFF('day', user_created_at, date_day))                                        AS days_since_user_creation,
  MAX(DATEDIFF('day', namespace_created_at, date_day))                                   AS days_since_namespace_creation,
  
  COUNT(*)                                                                               AS event_count,
  COUNT(DISTINCT TO_DATE(event_created_at))                                              AS event_day_count
FROM date_details
INNER JOIN gitlab_dotcom_usage_data_events 
  ON gitlab_dotcom_usage_data_events.event_created_at BETWEEN DATEADD('day', -28, date_details.date_day) AND date_day 
LEFT JOIN gitlab_subscriptions
  ON gitlab_dotcom_usage_data_events.namespace_id = gitlab_subscriptions.namespace_id
  -- taking the last day of the month
  AND DATEADD('day', -1, date_day) BETWEEN gitlab_subscriptions.valid_from
    AND {{ coalesce_to_infinity("gitlab_subscriptions.valid_to") }}
LEFT JOIN plans
  ON gitlab_subscriptions.plan_id = plans.plan_id
WHERE day_of_month = 1
{{ dbt_utils.group_by(n=9) }}