WITH source AS (

    SELECT *
    FROM {{ source('marketo', 'lead') }}

), renamed AS (

    SELECT
        --Primary Key
        id::FLOAT                                 AS marketo_lead_id,
        --Info
        email::VARCHAR                            AS email,
        {{ hash_of_column('EMAIL') }}
        sfdc_lead_id::VARCHAR                     AS sfdc_lead_id,
        sfdc_contact_id::VARCHAR                  AS sfdc_contact_id,
        first_name::VARCHAR                       AS first_name,
        last_name::VARCHAR                        AS last_name,
        company::VARCHAR                          AS company_name,
        title::VARCHAR                            AS job_title,
        {{it_job_title_hierarchy('job_title')}},
        country::VARCHAR                          AS country,
        mobile_phone::VARCHAR                     AS mobile_phone,
        sfdc_type::VARCHAR                        AS sfdc_type,
        inactive_lead_c::BOOLEAN                  AS is_lead_inactive,
        inactive_contact_c::BOOLEAN               AS is_contact_inactive,
        sales_segmentation_c::VARCHAR             AS sales_segmentation,
        is_email_bounced::BOOLEAN                 AS is_email_bounced,
        email_bounced_date::DATE                  AS email_bounced_date,
        unsubscribed::BOOLEAN                     AS is_unsubscribed,
        opt_in::BOOLEAN                           AS is_opt_in,
        compliance_segment_value::VARCHAR         AS compliance_segment_value,
        pql_product_qualified_lead_c::BOOLEAN     AS is_pql_marketo,
        cdbispaidtier_c::BOOLEAN                  AS is_paid_tier_marketo,
        ptpt_is_contact_c::BOOLEAN                AS is_ptpt_contact_marketo,
        ptp_is_ptp_contact_c::BOOLEAN             AS is_ptp_contact_marketo,
        cdb_impacted_by_user_limit_c::BOOLEAN     AS is_impacted_by_user_limit_marketo,
        currently_in_trial_c::BOOLEAN             AS is_currently_in_trial_marketo,
        trial_start_date_c::DATE                  AS trial_start_date_marketo,
        trial_end_date_c::DATE                    AS trial_end_date_marketo,
        updated_at::TIMESTAMP                     AS updated_at,
        _FIVETRAN_SYNCED,
        PRIORITY,
        URGENCY,
        RELATIVE_SCORE,
        RELATIVE_URGENCY,
        LEAD_SCORE,
        DEMOGRAPHIC_SCORE,
        LEAD_SOURCE,
        LEAD_STATUS,
        ACQUISITION_PROGRAM_ID,
        MKTO_ACQUISITION_DATE,
        PATH_FACTORY_ASSETS_VIEWED_C,
        PATH_FACTORY_CONTENT_COUNT_C,
        PATH_FACTORY_CONTENT_JOURNEY_C,
        PATH_FACTORY_ENGAGEMENT_SCORE_C,
        PATH_FACTORY_ENGAGEMENT_TIME_C,
        PATH_FACTORY_QUERY_STRING_C,
        BEHAVIOR_SCORE,
        GENERIC_EMAIL_DOMAIN,
        OPT_IN_DATE,
        RECORD_TYPE_ID_CONTACT,
        OWNER_PROFILE_C_LEAD,
        PHOTO_URL,
        STATE_CODE,
        MKTO_SI_SALES_INSIGHT_C,
        DEMANDBASE_SID_C,
        COUNTRY_CODE,
        SUB_REGION_C_LEAD,
        ACTIVE_USER_C,
        MKTO_SI_ADD_TO_MARKETO_CAMPAIGN_C,
        SALES_SEGMENTATION_C_LEAD,
        MQL_COUNTER_C,
        RAW_DATE_TIME_C,
        REGION_SUB_REGION_C_LEAD,
        CREATED_DATE_TIME_C,
        ZI_COMPANY_OTHER_DOMAINS_C,
        ATAM_SUB_REGION_C,
        ATAM_TERRITORY_C,
        TSP_UNIQUE_TERRITORY_NAME_C,
        ATAM_AREA_C,
        ATAM_REGION_C,
        BIZIBLE_2_ENGAGEMENT_SCORE_C,
        ATAM_APPROVED_NEXT_OWNER_C,
        ATAM_NEXT_OWNER_ROLE_C,
        ATAM_NEXT_OWNER_TEAM_C,
        ATAM_OWNER_DIFFERENCE_C,
        ATAM_OWNER_ROLE_ACRO_C,
        TSP_MANAGER_DIFFERENCE_C,
        MQL_DATE_C,
        INITIAL_MQL_DATE_C,
        INDUSTRY,
        ACTIVELY_BEING_SEQUENCED_C,
        NUMBER_OF_ACTIVE_SEQUENCES_C,
        SEQUENCE_STATUS_C,
        NURTURE_DATE_TIME_C,
        NURTURE_REASONS_C,
        OWNER_TEAM_C,
        REGION_C,
        BIZIBLE_2_LANDING_PAGE_FT_C,
        BIZIBLE_2_LANDING_PAGE_LC_C,
        BIZIBLE_2_MARKETING_CHANNEL_FT_C,
        BIZIBLE_2_MARKETING_CHANNEL_LC_C,
        BIZIBLE_2_TOUCHPOINT_DATE_FT_C,
        BIZIBLE_2_TOUCHPOINT_DATE_LC_C,
        BIZIBLE_2_TOUCHPOINT_SOURCE_FT_C,
        BIZIBLE_2_TOUCHPOINT_SOURCE_LC_C,
        LEAN_DATA_MATCHED_ACCOUNT_SALES_SEGMENT_C,
        LEAN_DATA_MATCHED_ACCOUNT_C,
        PATH_FACTORY_EXPERIENCE_NAME_C,
        PREVIOUS_NURTURE_REASON_C,
        PATH_FACTORY_ASSET_TYPE_C,
        PATH_FACTORY_CONTENT_LIST_C,
        PATH_FACTORY_FUNNEL_STATE_C,
        PATH_FACTORY_TOPIC_LIST_C,
        EMPLOYEE_BUCKETS_C,
        PHONE,
        WEBSITE,
        NEWSLETTER_SEGMENT_C_LEAD,
        SUBSCRIBE_WEBCAST_C,
        SUBSCRIBE_LIVE_EVENTS_C,
        GDPR_COMPLIANT_C,
        BIZIBLE_2_AD_CAMPAIGN_NAME_FT_C,
        BIZIBLE_2_AD_CAMPAIGN_NAME_LC_C,
        SIGN_UP_DATE,
        LEAN_DATA_TERRITORY_C,
        TRIAL_GIT_LAB_COM_C,
        OPT_OUT_DATE,
        SEC_PROJECT_NAMES,
        BIZIBLE_2_ACCOUNT_C,
        EMAIL_SUSPENDED,
        EMAIL_SUSPENDED_AT,
        EMAIL_SUSPENDED_CAUSE,
        LAST_UTM_CAMPAIGN_C,
        LAST_UTM_CONTENT_C,
        LAST_UTM_SOURCE_C,
        LAST_UTM_MEDIUM_C,
        PERSON_TIME_ZONE,
        ALL_REMOTE_FUNCTION,
        ALL_REMOTE_ROLE,
        DB_COMPANY_ADDRESS_C,
        DB_COMPANY_CITY_C,
        DB_COMPANY_COUNTRY_C,
        DB_COMPANY_NAME_C,
        DB_COMPANY_PHONE_C,
        DB_COMPANY_POSTAL_C,
        DB_COMPANY_STATE_C,
        DB_EMPLOYEE_COUNT_C,
        DB_INDUSTRY_C,
        DB_PRIMARY_SIC_C,
        DB_SUB_INDUSTRY_C,
        DB_WEBSITE_C,
        REASONFOR_ALL_REMOTE,
        GIT_LAB_COM_USER_C,
        ACCEPTED_DATE_TIME_C,
        NAME_OF_ACTIVE_SEQUENCE_C,
        EE_TRIAL_START_C,
        EE_TRIAL_START_DATE_C,
        TRIAL_ENTERPRISE_C,
        TRIAL_LICENSE_KEY,
        EE_TRIAL_END_DATE_C,
        PUBLIC_SECTOR_PARTNER_C,
        INITIAL_START_DATE_C,
        PARENT_ACCOUNT_SHIPPING_COUNTRY_C,
        VARTOPIA_DRS_DOMAIN_C,
        MAX_FOR_POTENTIAL_EE_USERS_C,
        MQL_DATE_TIME_C,
        ZENDESK_LAST_SYNC_DATE_C_LEAD,
        ORIGINAL_SOURCE_TYPE,
        ULTIMATE_PARENT_ACCOUNT_ZIP_DISC_ORG_F_3_C,
        COUNT_OF_OPEN_RENEWAL_OPPORTUNITIES_C,
        UNIQUE_WEB_VISITORS_ROLLING_30_C,
        ZI_COMPANY_NAICS_CODE_C,
        SALES_SEGMENTATION_UPDATED_C,
        CURRENT_CUSTOMER_C,
        NUMBER_OF_EMPLOYEES_DATA_FOX_C,
        REGISTRATION_SOURCE_TYPE,
        ZI_PRODUCTS_AND_SERVICES_C,
        DB_AUDIENCE_C,
        TZ_LT_INFO_C,
        ZZZ_ULT_PARENT_EMPLOYES_NUM_C,
        ULTIMATE_PARENT_SALES_SEGMENT_EMP_TEXT_C,
        VAT_ID_C,
        RECURLY_FIRST_NAME_C,
        BILLING_STATE_CODE,
        PARENT_ACCOUNT_SHIPPING_STATE_C,
        BUSINESS_DEVELOPMENT_REP_CONTACT_C,
        VARTOPIA_DRS_NUMBER_OF_EXPIRED_REGISTRATIONS_C_CONTACT,
        GS_PLAN_ACTIVE_C,
        ACCOUNT_PHONE_C,
        PRODUCTS_PURCHASED_C,
        VARTOPIA_DRS_CLOSED_WON_REGISTRATIONS_C_CONTACT,
        PUB_SEC_OWNER_C_LEAD,
        ZI_EMPLOYMENT_HISTORY_C,
        MKTO_COMPANY_NOTES,
        ENGAGIO_LEFT_COMPANY_C,
        DFOX_LAST_SYNCED_DATE_C_ACCOUNT,
        ENGAGIO_ENGAGEMENT_MINUTES_LAST_7_DAYS_C_ACCOUNT,
        RING_LEAD_STREET_ADDRESS_C,
        ZOOM_INFO_CONTACT_PROFILE_URL_C,
        LEAN_DATA_MATCHED_ACCOUNT_INDUSTRY_C,
        ADDRESS,
        TEMP_DF_PARENT_ACCOUNT_C,
        ENGAGIO_DEPARTMENT_C,
        ROUND_ROBIN_ID_C,
        LICENSE_UTILIZATION_C,
        ACTIVE_USER_C_ACCOUNT,
        ULTIMATE_PARENT_POTENTIAL_EEUSERS_C,
        ABM_TIER_3_DATE_C,
        DSCORGPKG_EMAIL_INVALID_C,
        GACID,
        ZI_CONTACT_ZIP_CODE_C,
        RING_LEAD_CITY_C,
        MIGRATION_SERVICES_REQUESTED,
        LICENSE_USER_COUNT_C,
        BDR_JOB_TITLE,
        GIT_LABCOM_USER_ID_C,
        DFOX_SOURCED_FROM_DATA_FOX_C_ACCOUNT,
        INDUSTRY_C,
        REGION_C_ACCOUNT,
        ACCOUNT_MANAGER_C,
        UPA_ACCOUNT_TERRITORY_ZIP_F_3_C,
        TWITTER_HANDLE_C,
        WEBCAST_SPEAKER_REFERENCE_C_ACCOUNT,
        AD_IMPRESSIONS_ROLLING_90_C,
        INFERRED_CITY,
        ZENDESK_CREATED_UPDATED_FLAG_C,
        ZENDESK_ZENDESK_ORGANIZATION_C,
        CHANNEL_MANAGER_C,
        TZ_TIMEZONE_C_ACCOUNT,
        RECURLY_PAST_DUE_C,
        ULTIMATE_PARENT_ACCOUNT_BILLING_STATE_C,
        NEXT_FY_USER_SEGMENT_TEMP_C,
        LEAN_DATA_MATCHED_ACCOUNT_NAME_C,
        EMAIL_2_C,
        ZENDESK_ZENDESK_ID_C,
        SALUTATION,
        COUNT_OF_COUNT_OF_CHILD_ACCOUNTS_C,
        DOZISF_ZOOM_INFO_LAST_UPDATED_C_ACCOUNT,
        ZI_CONTACT_STATE_C,
        PATH_FACTORY_CONTENT_SLUG_C,
        ULTIMATE_PARENT_ACCOUNT_ZIP_DATA_FOX_C,
        LEAN_DATA_MATCHED_ACCOUNT_EMPLOYEES_C,
        ZI_WEBSITE_C,
        NAMED_ACCOUNT_C,
        IMPLEMENTATION_SERVICE_REQUESTED,
        ALYCECOM_MOST_RECENT_GIFT_INVITATION_SENT_DATE_C_ACCOUNT,
        TEMP_DF_HIER_ULTIMATE_PARENT_BILLING_ZI_C,
        ZI_NUMBER_OF_DEVELOPERS_C,
        LEAN_DATA_MATCHED_ACCOUNT_BILLING_COUNTRY_C,
        ABM_TIER_C,
        RATINGSCALE,
        BUSINESS_DEVELOPMENT_REP_C_ACCOUNT,
        SPECIALIZED_TRAININGS_REQUESTED,
        COMPANY_LOCAL,
        MKTO_2_INFERRED_CITY_C,
        NEXT_FY_PLANNING_NOTES_TEMP_C,
        HOME_OFFICE_CITY,
        SHIPPING_LATITUDE,
        TZ_TIMEZONE_IANA_C,
        DSCORGPKG_JOB_FUNCTION_C,
        TZ_TIMEZONE_C,
        EVENT_MEETING_TIME,
        NUMBER_OF_LICENSES_C,
        COMPANY_NATURAL_NAME_C,
        ACCOUNT_ADDRESS_MANUAL_SOURCE_USER_C,
        DOZISF_ZOOM_INFO_FIRST_UPDATED_C,
        QUALIFYING_DATE_TIME_C,
        MKTO_71_ORIGINAL_UTM_MEDIUM_C,
        RECURLY_PLAN_NAME_C,
        LAST_UTM_OFFERTYPE_C,
        ULTIMATE_PARENT_ACCOUNT_COUNTRY_DATA_FOX_C,
        RECURLY_ACCOUNT_CODE_C,
        ACCOUNT_ID_18_C,
        SFDC_LEAD_OWNER_ID,
        ZI_MANAGEMENT_LEVEL_C,
        ZI_COMPANY_EMPLOYEE_RANGE_C,
        ZI_COMPANY_CITY_C,
        GS_MONITORING_ACTIVE_C,
        ENGAGIO_MATCHED_ACCOUNT_ENGAGE_MINS_LAST_7_DAYS_C,
        BDR_LAST_NAME,
        RECURLY_PLAN_CODE_C,
        SDR_C,
        MATCHED_ACCOUNT_GTM_STRATEGY_C,
        CITY,
        VARTOPIA_DRS_NUMBER_OF_CLOSED_WON_REGISTRATIONS_C_CONTACT,
        NDE_NODE_GENERATED_CHECKBOX_C,
        GIT_LAB_COM_USER_C_ACCOUNT,
        B_TLKWEBCAST_CAMPAIGN_REFERENCE,
        RING_LEAD_STATE_C,
        LEAN_DATA_MATCHED_ACCOUNT_WEBSITE_C,
        CORE_USER_C,
        ROLE_C,
        TZ_TIMEZONE_FULL_C,
        SIG_REFERENCE_C_ACCOUNT,
        SOLUTIONS_TO_BE_REPLACED_C,
        RING_LEAD_COUNTRY_C,
        INTENT_C,
        DOZISF_ZOOM_INFO_ID_C,
        ZI_COMPANY_ZIP_CODE_C,
        CONTACT_COMPANY,
        CORE_CHECK_IN_NOTES_FORMATTED_2_C,
        ZENDESK_RESULT_C_LEAD,
        RING_LEAD_PHONE_C,
        UNQUALIFIED_DATE_TIME_C,
        B_TLKRECORDED_MINUTES_VIEWED,
        B_TLKWEBCAST_TITLE,
        ENGAGIO_MATCHED_ACCOUNT_EMPLOYEES_C,
        LOCALLY_MANAGED_C,
        SDR_ASSIGNED_C,
        TRENDING_OFFSITE_INTENT_C,
        ANONYMOUS_IP,
        VERIFY_ACTIVE_C,
        ULTIMATE_PARENT_ACCOUNT_ZIP_DISC_ORG_C,
        BDR_FIRST_NAME,
        MARKETING_COMM_OPT_OUT_C_ACCOUNT,
        CORE_CHECK_IN_NOTES_C,
        WON_RENEWAL_OPP_THIS_MONTH_C,
        COUNT_OF_CROSS_SELL_OPPS_C,
        HEALTH_C,
        BDR_EMAIL_ADDRESS,
        ACCOUNT_C,
        ZI_STREET_C,
        ZENDESK_LAST_SYNC_DATE_C,
        ULTIMATE_PARENT_ADDRESS_SOURCE_FORMULA_C,
        IS_PARTNER,
        ENTITY_BENEFICIARY_INFORMATION_C,
        ZI_CONTACT_STREET_C,
        TSP_LAST_CHANGE_DATE_C,
        TECH_STACK_C,
        INTERESTED_IN_GIT_LAB_EE_C,
        ALLIANCES_DISCOUNT_C,
        GS_LIFECYCLE_STAGE_C,
        WORLD_TOUR_CITY,
        ST_MONITOR_APPETITE_FOR_REPLACEMENT_C,
        ULTIMATE_PARENT_OLD_C,
        ULTIMATE_PARENT_ACCOUNT_SHIPPING_STATE_C,
        DEPARTMENT,
        PREVIOUS_UNQUALIFIED_REASON,
        HOME_OFFICE_POSTAL_CODE,
        FREE_COM_USER_C,
        ENGAGIO_MATCHED_ACCOUNT_TYPE_C,
        ZI_CITY_C,
        TERMINUS_CLICKS_C_ACCOUNT,
        LOGO_REFERENCE_C_ACCOUNT,
        OSS_REASON_FOR_APPLICATION_C,
        PATH_FACTORY_CONTENT_LANGUAGE_C,
        HOW_ARE_YOU_USING_GIT_LAB_C,
        DATA_FOX_PARENT_ACCOUNT_WORK_TEMP_C,
        ENGAGIO_STATUS_C,
        TEMP_DF_HIER_ULTIMATE_PARENT_NAMED_C,
        ENGAGIO_ROLE_C,
        TEMP_ULTIMATE_PARENT_ID_MATCH_C,
        IACV_THIS_ACCOUNT_Q_4_2018_C,
        SDR_ASSIGNED_ROLE_C,
        SUPPORT_LEVEL_NUMERIC_C,
        IS_LEAD,
        SURGE_HEAT_C,
        CUSTOMER_C,
        ZI_COMPANY_COUNTRY_C,
        VARTOPIA_DRS_TOTAL_NUMBER_OF_REGISTRATIONS_C_CONTACT,
        STATE,
        LEAN_DATA_MATCHED_ACCOUNT_TYPE_C,
        ENGAGIO_NUMBER_OF_PEOPLE_C,
        PLAN_ACTIVE_C,
        ENGAGIO_PIPELINE_PREDICT_SCORE_C,
        ZI_ULTIMATE_PARENT_COMPANY_ZOOMINFO_ID_C,
        B_TLKTOTAL_MINUTES_VIEWED,
        WEBCAST_ACTIVITY_ACTIVITY_TYPE,
        VARTOPIA_DRS_NUMBER_OF_APPROVED_REGISTRATIONS_C_CONTACT,
        ALERTS_C,
        ZI_ACCOUNT_NAME_C,
        PARTNERS_IS_ACTIVE_C,
        ZENDESK_RESULT_C,
        VARTOPIA_DRS_CLOSED_LOST_REGISTRATIONS_C_CONTACT,
        SECURE_ACTIVE_C,
        MARKETING_SUSPENDED,
        COOKIES,
        DIETARY_RESTRICTION_C,
        TZ_TIMEZONE_FULL_C_ACCOUNT,
        ZI_NAICS_CODE_C,
        ACCOUNT_TERRITORY_C,
        ENGAGIO_QUALIFICATION_SCORE_C,
        NDE_NODE_CONTEXT_FORMULA_C_ACCOUNT,
        COMPANY_SEARCH_QUERY_C,
        SALES_REFERENCE_C_ACCOUNT,
        COUNT_OF_OPPORTUNITIES_C,
        ZI_TOTAL_FUNDING_C,
        SUB_INDUSTRY_C_ACCOUNT,
        IS_A_CONTRACTED_PARTNER_C,
        PUB_SEC_OWNER_C,
        ORIGINAL_SOURCE_INFO,
        M_QLDATE_2,
        INFER_INFER_SCORE_C,
        TEMP_DF_HIER_ULTIMATE_PAR_BILL_COUNTRY_C,
        ZI_COMPANY_STATE_C,
        ACCOUNT_OWNER_C,
        ENGAGIO_MATCH_TIME_C,
        REGISTRATION_SOURCE_INFO,
        ZI_COUNTRY_C,
        CUSTOMER_HEALTH_SCORE_DATE_C,
        ULTIMATE_PARENT_SALES_SEGMENT_EMPLOYEES_C,
        ATAM_ADDRESS_POSTAL_CODE_C,
        GS_SECURITY_ACTIVE_C,
        IACV_THIS_ACCOUNT_Q_3_2018_C,
        ACCOUNT_STREET_ADDRESS_MANUAL_ADMIN_C,
        DOMAINS_C,
        EMAIL_OPT_OUT_C,
        EVENTS_SEGMENT,
        ULTIMATE_PARENT_SALES_SEGMENTATION_C,
        ANNUAL_REVENUE,
        ZI_CONTACT_ACCURACY_GRADE_C,
        ZI_FAX_C,
        IS_CONTACT_C,
        PERSON_PRIMARY_LEAD_INTEREST,
        PHOTO_URL_ACCOUNT,
        ATTEND_ORGANIZED_GIT_LAB_MEETUP_C,
        TECHNICAL_ACCOUNT_MANAGER_C,
        GENERIC_1,
        TEMP_DUPLICATED_ACCOUNT_C,
        ZI_COMPANY_REVENUE_RANGE_C,
        DOUBLE_OPT_IN_DATE,
        ZI_EMPLOYEES_C,
        SUPPORT_EDU_OSS_C,
        O_SSCERTIFIED_NOTFOR_PROFIT,
        ENGAGIO_ENGAGEMENT_MINUTES_LAST_3_MONTHS_C,
        MKTO_71_ORIGINAL_UTM_SOURCE_C,
        CAB_REFERENCE_C,
        BLACK_LISTED,
        ZENDESK_IS_CREATED_UPDATED_FLAG_C,
        DO_NOT_ROUTE_C,
        GTM_STRATEGY_C,
        BILLING_POSTAL_CODE,
        ABERDEEN_CLOUD_PROVIDER_C,
        CONVERTED_DATE_C,
        MAIN_PHONE,
        IF_USING_CE_HOW_ARE_YOU_USING_CE_C,
        ENTITY_OVERRIDE_C,
        COMPANY_DESC_RESELLER_C,
        IS_GIT_LAB_GEO_CUSTOMER_C,
        FAX,
        ZENDESK_ZENDESK_OUTOF_SYNC_C,
        IMPARTNER_PRM_IS_DEAL_REGISTRATION_C,
        ZI_STATE_PROVINCE_C,
        WEB_PORTAL_PURCHASE_DATE_TIME_C,
        B_TLKQUESTIONS_TEXT,
        TOTAL_ACCOUNT_VALUE_C,
        UNQUALIFIED_REASONS_C,
        PRINTFECTION_CODE,
        VARTOPIA_DRS_DENIED_REGISTRATIONS_C_CONTACT,
        INFERRED_PHONE_AREA_CODE,
        MAILING_COUNTRY_CODE,
        ZI_COMPANY_IS_DEFUNCT_C,
        ZI_INDUSTRY_C,
        ULTIMATE_PARENT_ACCOUNT_STATE_DATA_FOX_C,
        LEAN_DATA_OWNER_C,
        ACCOUNT_STATE_MANUAL_USER_C,
        LAST_TSP_UPDATE_REASON_C,
        DOMAIN_C,
        ULTIMATE_PARENT_ACCOUNT_BILLING_ZIP_C,
        LEAD_OWNER_SLACK_ID,
        ZI_ULTIMATE_PARENT_COMPANY_NAME_C,
        IS_SP_URL_FILLED_C,
        OSS_PROJECT_LINK_C,
        LEAD_PERSON,
        BILLING_LONGITUDE,
        ZI_EMPLOYEE_COUNT_C,
        DOUBLE_OPT_IN,
        MATCHED_ACCOUNT_SDR_ASSIGNED_C,
        MKTO_2_INFERRED_STATE_REGION_C,
        RECURLY_LAST_NAME_C,
        VARTOPIA_DRS_NUMBER_OF_CLOSED_LOST_REGISTRATIONS_C_CONTACT,
        LAST_UNIQUE_VISITORS_SNAPSHOT_C,
        MAILING_ADDRESS,
        ULTIMATE_PARENT_ACCOUNT_SEGMENT_ROLLUP_C,
        SUBSCRIBERS_BRIGHT_TALKUSER_ID,
        PARTNER_ACCOUNT_C,
        EO_ACUSTOMER_NAME,
        PRODUCT_CATEGORY_C,
        BILLING_STREET,
        ZI_CONTACT_ACCURACY_SCORE_C_CONTACT,
        B_TLKVIEWING_URL,
        INFERRED_POSTAL_CODE,
        NDE_NODE_GENERATED_FORMULA_C,
        CE_DOWNLOAD_DATE,
        INFERRED_COMPANY,
        GS_CI_ACTIVE_C,
        ENTITY_CONTACT_INFORMATION_C,
        ACCOUNT_OWNER_MANAGER_EMAIL_C,
        NEXT_FY_USER_REGION_TEMP_C,
        ZI_CONTACT_ACCURACY_SCORE_C,
        CE_INSTANCES_C,
        ZI_DESCRIPTION_C,
        CMRR_ALL_ACCOUNTS_C,
        PARENT_ACCOUNT_SHIPPING_ZIP_C,
        EDUCATION_REQUESTED,
        TSP_LAST_UPDATE_TIMESTAMP_C,
        MIDDLE_NAME_LEAD,
        NUMBER_OF_DEVELOPERS_BUCKET_C,
        ZI_CONTACT_COUNTRY_C,
        HOW_CAN_WE_HELP_C,
        VARTOPIA_DRS_NUMBER_OF_DENIED_REGISTRATIONS_C_CONTACT,
        ZENDESK_LAST_SYNC_STATUS_C,
        TEMP_DF_HIER_ULTIMATE_PARENT_SHIPPING_S_C,
        DATA_QUALITY_SCORE_C,
        MKTO_2_LEAD_SCORE_C,
        RING_LEAD_EMAIL_ADDRESS_C,
        ACCOUNT_COUNTRY_MANUAL_USER_C,
        COMMENT_CAPTURE,
        MATCHED_ACCOUNT_TERRITORY_C,
        SHIPPING_COUNTRY_CODE_C,
        HOME_OFFICE_COUNTRY,
        ACCOUNT_OWNER_TEAM_C,
        ACCOUNT_OWNER_EMAIL_C,
        RECURLY_UUID_C,
        ZENDESK_ZENDESK_ORGANIZATION_ID_C,
        LAST_UTM_TERM_C,
        COUNT_OF_OPEN_NEW_ADD_ON_OPPS_C,
        ZI_COMPANY_TICKER_C,
        ENGAGIO_MATCHED_ACCOUNT_ENGAGIO_STATUS_C,
        FIELD_MARKETING_MANAGER_C,
        ALLIANCE_RECORD_C_ACCOUNT,
        ST_PACKAGE_CONTRACT_END_DATE_C,
        TOTAL_CUSTOMER_VALUE_C,
        CUSTOMER_SINCE_C,
        ZQU_COUNTY_C,
        ZI_CERTIFICATION_DATE_C,
        VARTOPIA_DRS_CREATED_FROM_REGISTRATION_C_CONTACT,
        BUSINESS_DEVELOPMENT_REPRESENTATIVE_C,
        MKTO_71_ORIGINAL_UTM_TERM_C,
        ZI_REVENUE_C,
        MKTO_SI_SALES_INSIGHT_C_ACCOUNT,
        ENGAGIO_ENGAGEMENT_MINUTES_LAST_7_DAYS_C,
        MKTO_71_ORIGINAL_UTM_CAMPAIGN_C,
        ACCOUNT_STREET_MANUAL_USER_C,
        USING_CE_C_LEAD,
        SOLUTIONS_FEATURES_OF_INTEREST_C,
        SUCCESS_ENGINEER_C,
        ENGAGIO_MATCHED_ACCOUNT_ENGAGE_MINS_LAST_3_MONTHS_C,
        SUBSCRIBE_SUBPROCESSOR,
        VARTOPIA_DRS_VARTOPIA_PARTNER_TRANSACTION_ID_C,
        ST_MONITOR_TECH_C,
        ULTIMATE_PARENT_C,
        AD_IMPRESSIONS_ROLLING_30_C,
        GEMSTONE_TYPE_C,
        ST_PLAN_TECH_C,
        OUTBOUND_BDR_C,
        ACCOUNT_STATE_MANUAL_ADMIN_C,
        TZ_TIMEZONE_IANA_C_ACCOUNT,
        LEAN_DATA_MATCHED_ACCOUNT_BILLING_STATE_C,
        VARTOPIA_DRS_APPROVED_REGISTRATION_C,
        ZI_COMPANY_LINKED_IN_URL_C,
        WEB_VISIT_DATA_UP_TO_DATE_AS_OF_C,
        BILLING_LATITUDE,
        ACCOUNT_CITY_MANUAL_USER_C,
        ENGAGIO_MQADATE_C,
        ZI_TICKER_SYMBOL_C,
        OSS_SUPPORTING_EVIDENCE_C,
        RECORD_TYPE_ID,
        PERSON_TYPE,
        NDE_NODE_GENERATED_LEAD_FORMULA_C,
        AE_COMMENTS_C_CONTACT,
        UPA_ACCOUNT_TERRITORY_ZIP_C,
        EMAIL_BOUNCED_REASON,
        TOTAL_TECH_ENG_DESIGN_DEV_USERS_C,
        NEXT_FY_USER_AREA_TEMP_C,
        ULTIMATE_PARENT_ACCOUNT_SHIPPING_COUNTRY_C,
        NDE_NODE_PRIORITY_C,
        NAME_LOCAL,
        SIC_CODE,
        VARTOPIA_DRS_VARTOPIA_ACCESS_C,
        CURRENT_MRR_C,
        LEAN_DATA_REGION_C,
        ATAM_ADDRESS_CITY_C,
        ABERDEEN_TECHNOLOGY_STACK_C,
        UPA_ACCOUNT_TERRITORY_STATE_C,
        COMPETITORS_C,
        OSS_PROJECT_DESCRIPTION_C,
        Y_CBATCH,
        FIRST_ORDER_AVAILABLE_C,
        SOLUTIONS_ARCHITECT_C,
        B_TLKACTIVITY_MESSAGE,
        ULTIMATE_PARENT_ID_C,
        DOZISF_ZOOM_INFO_FIRST_UPDATED_C_ACCOUNT,
        BAD_DATA_DATE_TIME_C,
        NDE_YOU_SHOULD_MENTION_C_ACCOUNT,
        X_30_DAY_OPT_OUT_C,
        LAST_NAME_LOCAL,
        WEB_VISITS_ROLLING_30_C,
        PRODUCTS_SOLD_RESELLER_C,
        PREVIOUS_BAD_DATA_REASON,
        TSP_OVERRIDE_STATUS_C,
        BILLING_STATE,
        MAILING_STATE_CODE,
        CAB_REFERENCE_C_ACCOUNT,
        BDR_PHONE_NUMBER,
        PRODUCT_OSS_EDU_C,
        DB_COMPANY_CITY_C_CONTACT,
        TEMP_DF_PARENT_ACCOUNT_ID_C,
        POTENTIAL_USERS_C,
        SFSSDUPE_CATCHER_OVERRIDE_DUPE_CATCHER_C,
        TEMP_DF_HIER_ULTIMATE_PAR_SHIP_COUNTRY_C,
        PARENT_ACCOUNT_OWNER_C,
        FEDERAL_ACCOUNT_C,
        LATEST_LEAD_CONVERSION_NUMBER_OF_EMPLOY_C,
        BILLING_COUNTRY_CODE,
        ULTIMATE_PARENT_ACCOUNT_ZIP_DATA_FOX_F_3_C,
        PATH_FACTORY_EXTERNAL_ID_C,
        PARENT_ACCOUNT_BILLING_STATE_C,
        ENGAGIO_MATCHED_ACCOUNT_HQ_STATE_C,
        PARENT_ACCOUNT_BILLING_ZIP_C,
        MAILING_LONGITUDE,
        ACCOUNT_ADDRESS_MANUAL_DATE_O_C,
        DEV_OPS_VIRTUAL_CUSTOM_C,
        LEAN_DATA_REPORTING_TARGET_ACCOUNT_C,
        PACKAGE_ACTIVE_C,
        ALLIANCE_RECORD_C,
        HEALTH_SCORE_REASONS_C,
        LEAD_PARTITION_ID,
        RING_LEAD_ZIP_POSTAL_CODE_C,
        SHIPPING_COUNTRY_CODE,
        CONSENT_TO_DATA_SHARING_WITH_WHITESOURCE_C,
        ZENDESK_LAST_SYNC_STATUS_C_LEAD,
        TEMP_DF_ULTIMATE_PARENT_ACCOUNT_LU_C,
        AD_CLICKS_ROLLING_90_C,
        NON_CRIMEAN_C,
        ZI_TECHNOLOGIES_C,
        ZI_PARENT_COMPANY_NAME_C,
        ASSOCIATED_TERMINUS_ACCOUNTS_C,
        TECHNICAL_ACCOUNT_MANAGER_LU_C,
        JB_TEST_SALES_SEGMENT_C,
        BILLING_COUNTRY,
        LAST_EVENT_NOTES_C,
        CASE_STUDY_REFERENCE_C_ACCOUNT,
        TEMP_DF_HIER_ULTIMATE_PARENT_SHIPPING_Z_C,
        ULTIMATE_PARENT_SALES_SEGMENTATION_DEL_C,
        ORIGINAL_SEARCH_ENGINE,
        ULTIMATE_PARENT_ACCOUNT_STATE_DISC_ORG_C,
        RING_LEAD_GENERAL_ARCHIVE_C,
        ZI_CONTACT_CITY_C,
        B_TLKWEBCAST_ID,
        NUMBER_OF_EMPLOYEES,
        GS_CD_ACTIVE_C,
        NDE_NODE_PRIORITY_C_CONTACT,
        ENGAGIO_MATCHED_ACCOUNT_OWNER_NAME_C,
        ABERDEEN_NUMBER_OF_DEVELOPERS_C,
        LEAN_DATA_MATCHED_ACCOUNT_BILLING_POSTAL_CODE_C,
        GS_SCM_ACTIVE_C,
        ENGAGIO_WEB_VISITS_LAST_3_MONTHS_C,
        NDE_NODE_CONTEXT_FORMULA_C,
        CIMINUTEUSAGE,
        ORIGINAL_REFERRER,
        DSCORGPKG_IT_BUDGET_C_ACCOUNT,
        ACCOUNT_CITY_MANUAL_ADMIN_C,
        SDR_ACCOUNT_TEAM_C,
        JOIN_URL,
        B_TLKLAST_ACTIVITY_DATE,
        DSCORGPKG_FISCAL_YEAR_END_C_ACCOUNT,
        ST_PLAN_CONTRACT_END_DATE_C,
        ZENDESK_TAGS_C,
        TZ_UTF_OFFSET_C,
        ULTIMATE_PARENT_SALES_SEGMENT_TEXT_C,
        EVENT_SPEAKER_REFERENCE_C,
        OUTREACH_STAGE_C,
        LEAN_DATA_MATCHED_ACCOUNT_ANNUAL_REVENUE_C,
        ROLE_PROSPECT_PLAYS_IN_EVALUATION_C,
        ENGAGIO_ENGAGEMENT_MINUTES_LAST_3_MONTHS_C_ACCOUNT,
        GATRACKID_C,
        SHIPPING_LONGITUDE,
        NDE_NODE_CONTEXT_C,
        ULTIMATE_PARENT_ACCOUNT_NAMED_C,
        FIRST_NAME_LOCAL,
        NDE_NODE_GENERATED_C,
        HIGH_LEVEL_BUSINESS_NEED_IMPACT_ON_BIZ_C,
        TERMINUS_IMPRESSIONS_C_ACCOUNT,
        SHIPPING_STATE_CODE,
        ZI_COMPANY_REVENUE_C,
        MKTO_IS_PARTNER,
        MKTO_NAME,
        INQUIRY_DATE_TIME_C,
        AATEST_C,
        DOAC_REFERENCE_C_ACCOUNT,
        MAILING_LATITUDE,
        NEXT_FY_TSP_TERRITORY_TEMP_C,
        INFERRED_METROPOLITAN_AREA,
        PATH_FACTORY_TRACK_CUSTOM_URL_C,
        ZENDESK_CREATE_IN_ZENDESK_C_ACCOUNT,
        DATA_QUALITY_DESCRIPTION_C_ACCOUNT,
        ZI_MOBILE_PHONE_NUMBER_C,
        ENTITY_BANK_INFORMATION_C,
        ULTIMATE_PARENT_IS_CURRENT_ACCOUNT_C,
        TEMP_DF_ULTIMATE_PARENT_ACCOUNT_C,
        TALK_ABOUT_GIT_LAB_C,
        ENGAGIO_ENGAGED_PEOPLE_C,
        NDE_NODE_CONTEXT_C_ACCOUNT,
        ULTIMATE_PARENT_ACCOUNT_SHIPPING_ZIP_C,
        HOME_OFFICE_STREET,
        TEMP_DF_HIER_ULTIMATE_PARENT_OWNER_C,
        IS_GIT_LAB_EECUSTOMER_C,
        SUBSCRIBED_SECURITY_ALERTS_C,
        SOLUTIONS_ARCHITECT_LOOKUP_C,
        ZENDESK_CREATE_IN_ZENDESK_C,
        INITIAL_MQL_DATE_TIME_C,
        GS_HEALTH_SCORE_LABEL_C,
        PARTNER_ACCOUNT_ID,
        ZI_PHONE_C,
        EVENT_SPEAKER_REFERENCE_C_ACCOUNT,
        CONTRACTED_CHANNEL_TEAM_USE_ONLY_C,
        LEAN_DATA_ROUTING_STATUS_C,
        SUBSCRIPTION_AMOUNT_C,
        PATH_FACTORY_TRACK_ID_C,
        TEMP_DATA_FOX_MIS_MATCH_C,
        ENGAGIO_INTENT_MINUTES_LAST_30_DAYS_C_ACCOUNT,
        ASSOCIATED_TERMINUS_ACCOUNTS_UP_TO_DATE_AS_OF_C,
        GCLID,
        COUNT_OF_OPEN_RENEWAL_OPPS_C,
        ZI_COMPANY_STREET_C,
        EDUCATION_USER_CASE_C,
        PARTNERS_PUBLIC_SECTOR_PARTNER_C,
        ANALYST_REFERENCE_C_ACCOUNT,
        ENGAGIO_MATCHED_ACCOUNT_C,
        CUSTOMER_SLACK_CHANNEL_C,
        HAS_OPTED_OUT_OF_FAX,
        VARTOPIA_DRS_COMPANY_ADMIN_C,
        DOZISF_ZOOM_INFO_LAST_UPDATED_C,
        ENGAGIO_MATCHED_ACCOUNT_NAME_C,
        SUBSCRIBE_PARTNERS,
        INFERRED_STATE_REGION,
        OTHER_COUNTRY_CODE,
        ULTIMATE_PARENT_ACCOUNT_OWNER_C,
        EDUCATION_USE_CASE_NOTES_C,
        ACCOUNT_TIER_NOTES_HISTORY_C,
        CURRENT_DEV_OPS_OR_SDLC_TOOLS_NOTES_C,
        SFSSDUPE_CATCHER_OVERRIDE_DUPE_CATCHER_C_CONTACT,
        PATH_FACTORY_CONTENT_SOURCE_URL_C,
        REGION_SUB_REGION_C,
        POTENTIAL_EE_USERS_TOTAL_C,
        DB_COMPANY_COUNTRY_C_CONTACT,
        ISGROUPNAMESPACEOWNER_C,
        MARKETING_COMM_OPT_OUT_C,
        DB_COMPANY_STATE_C_CONTACT,
        BAD_DATA_REASONS_C,
        LAST_VISIT_MOMENT_C,
        ZI_EMPLOYEE_COUNT_C_CONTACT,
        HOW_MANY_SEATS_ARE_THEY_INTERESTED_IN_PU_C,
        NDE_NODE_PRIORITY_C_ACCOUNT,
        CONTRIBUTED_TO_OPEN_SOURCE_C,
        LAST_VISIT_SESSIONS_SNAPSHOT_C,
        RECURLY_SUBSCRIBER_C,
        INTERESTED_IN_HOSTED_SOLUTION_C,
        VIDEO_TESTIMONIAL_REFERENCE_C_ACCOUNT,
        SUCCESS_PLAN_URL_C,
        AD_DATA_UP_TO_DATE_AS_OF_C,
        LEAN_DATA_SUB_REGION_C,
        EVENT_DATE_CODE,
        ACCOUNT_OWNERSHIP_NOTES_C,
        POTENTIAL_EE_USERS_C,
        ZI_CERTIFIED_ACTIVE_COMPANY_C,
        ACCOUNT_TYPE_C,
        POSTAL_CODE,
        LAST_SALE_VIA_PARTNER_C,
        MKTO_2_INFERRED_COUNTRY_C,
        MKTO_PERSON_NOTES,
        LAST_AD_CLICK_DATE_C,
        NEXT_FY_ACCOUNT_OWNER_TEMP_C,
        TEMP_ULTIMATE_PARENT_ACCOUNT_DISCO_ORG_ID_C,
        ENGAGIO_IN_PLAY_C,
        CREATED_AT,
        OSS_GIT_LAB_PROFILE_C,
        ZI_NAICS_CODE_C_LEAD,
        BUSINESS_DEVELOPMENT_REP_C,
        TZ_LT_INFO_C_ACCOUNT,
        EDUCATION_LICENSE_USAGE_C,
        E_EP_91_RELEASE_LICENSE_KEY,
        CREATE_ACTIVE_C,
        UPA_IS_HOLDING_COMPANY_C,
        WEBCAST_SPEAKER_REFERENCE_C,
        MKTO_71_ORIGINAL_UTM_CONTENT_C,
        ZI_WITHIN_EU_C,
        HOLDING_COMPANY_NAME_C,
        LAST_EMAIL_DATE_1,
        ATAM_ADDRESS_STREET_C,
        PATH_FACTORY_CONTENT_TITLE_C,
        SUBSCRIBE_ALL_REMOTE,
        REQUEST_FOR_LEAD_CONVERSION_C,
        SUB_REGION_C,
        DATA_QUALITY_DESCRIPTION_C,
        RELEASE_ACTIVE_C,
        SURVEY_NAME,
        DOZISF_ZOOM_INFO_COMPANY_ID_C,
        TERRITORIES_COVERED_C,
        ENGAGIO_TOP_URLS_C,
        PARTNERS_PARTNER_STATUS_C,
        VARTOPIA_DRS_EXPIRED_REGISTRATIONS_C_CONTACT,
        TRIGGER_WORKFLOW_C_LEAD,
        RECURLY_IN_TRIAL_C,
        ENTITY_C,
        MANAGE_ACTIVE_C,
        EVENTATTENDAGAIN,
        DEPLOYMENT_PREFERENCE_C,
        ULTIMATE_PARENT_SALES_SEGMENT_TEXT_DEL_C,
        DIGITAL_OCEAN_PROMO_CODE_C,
        ULTIMATE_PARENT_ADDRESS_COUNTRY_C,
        ZI_SUPPLEMENTAL_EMAIL_C,
        B_TLKLIVE_MINUTES_VIEWED,
        ENGAGIO_FIRST_ENGAGEMENT_DATE_C,
        DFOX_ID_C_ACCOUNT,
        ZI_ZOOM_INFO_CONTACT_PROFILE_URL_C,
        TZ_UTF_OFFSET_C_ACCOUNT,
        USING_CE_C,
        TERMINUS_SPEND_C_ACCOUNT,
        SFSSDUPE_CATCHER_OVERRIDE_DUPE_CATCHER_C_ACCOUNT,
        ESTIMATE_TOTAL_SEATS_AVAIL_AT_COMPANY_C,
        DO_NOT_CONTACT_C,
        FY_22_ON_BRONZE_STARTER_C,
        COUNT_OF_CUSTOMER_ONBOARDINGS_1_4_C,
        HOME_OFFICE_STATE,
        ORIGINAL_SEARCH_PHRASE,
        ZI_PARENT_COMPANY_ZOOMINFO_ID_C,
        MKTO_IS_CUSTOMER,
        LEAN_DATA_REPORTING_TARGET_ACCOUNT_NUMBER_C,
        DOZISF_ZOOM_INFO_ID_C_ACCOUNT,
        IS_ANONYMOUS,
        SUFFIX,
        HAMSTER_RENEWAL_DATE,
        NDE_NODE_PRIORITY_FORMULA_C,
        IS_FILE_LOCKING_CUSTOMER_C,
        MKTO_2_INFERRED_COMPANY_C,
        ATAM_ACCOUNT_CARR_C,
        OUTBOUND_BDR_C_CONTACT,
        B_TLKQUESTIONS_ANSWERED,
        EMAIL_INVALID_CAUSE,
        ECUSTOMS_IM_STATUS_C_ACCOUNT,
        TERMINUS_VELOCITY_LEVEL_C_ACCOUNT,
        COMMENT_HISTORY,
        UNSUBSCRIBED_REASON,
        ZENDESK_NOTES_C_LEAD,
        CE_DOWNLOAD,
        BUYING_PROCESS_FOR_PROCURING_GIT_LAB_C,
        WEB_FORM_C,
        RECURLY_CLOSED_C,
        IS_CONTRACTED_PARTNER_C,
        ACCOUNT_TIER_C,
        CMRR_ALL_CHILD_ACCOUNTS_C,
        ZI_INDUSTRY_C_LEAD,
        ST_PACKAGE_TECH_C,
        ATAM_ADDRESS_STATE_C,
        IMPARTNER_PRM_DEAL_REGISTRATION_STATUS_C,
        RECURLY_COMPANY_C,
        ZI_COMPANY_DESCRIPTION_C,
        NDE_NODE_PRIORITY_FORMULA_C_ACCOUNT,
        ATAM_GEO_STORY_C,
        QUOTE_REFERENCE_C_ACCOUNT,
        DSCORGPKG_LEAD_SOURCE_C,
        QUALIFIED_DATE_TIME_C,
        ST_PLAN_APPETITE_FOR_REPLACEMENT_C,
        MATCHED_STATUS,
        ZI_ZIP_POSTAL_CODE_C,
        ENGAGIO_FIRST_ENGAGEMENT_DATE_C_ACCOUNT,
        AD_CLICKS_ROLLING_30_C,
        ZI_SIC_CODE_C,
        NEXT_FY_USER_GEO_TEMP_C,
        PARENT_ACCOUNT_BILLING_COUNTRY_C,
        ENGAGIO_HIGH_INTENT_KEYWORDS_C,
        RECURLY_UPDATED_AT_C,
        PERSON_SCORE_2,
        EDUCATION_ROLE_C,
        NDE_YOU_SHOULD_MENTION_C,
        NEW_LOGO_TARGET_ACCOUNT_C,
        ACCOUNT_ZIP_MANUAL_USER_C,
        SALES_SEGMENTATION_NEW_C,
        ECCN_QUARANTINE_C,
        DO_NOT_CALL,
        WEB_PORTAL_PURCHASE_COMPANY_SIZE_C,
        ATAM_ADDRESS_COUNTRY_C,
        COUNT_OF_OPEN_RENEWAL_OPPS_THIS_MONTH_C,
        TEMP_DF_HIER_ULTIMATE_PARENT_SEGMENT_E_C,
        ACCOUNT_COUNTRY_MANUAL_ADMIN_C,
        ENTITY_LEGAL_NAME_C,
        EVENT_DATE_CODE_4,
        EVENT_DATE_CODE_3,
        ENGAGIO_MATCHED_ACCOUNT_INDUSTRY_C,
        EVENT_DATE_CODE_2,
        EVENT_DATE_CODE_1,
        DO_NOT_CALL_REASON,
        OPEN_SOURCE_LICENSE_C,
        ZI_TECHNOLOGIES_C_LEAD,
        TEMP_DF_HIER_ULTIMATE_PARENT_BILLING_ST_C,
        TRANSFER_DATE_C,
        JB_OLD_SS_C,
        EMAIL_INVALID,
        SFDC_ACCOUNT_ID,
        IS_GIT_HOST_CUSTOMER_C,
        ACCOUNT_TIER_NOTES_C,
        DATA_QUALITY_SCORE_C_ACCOUNT,
        NEXT_RENEWAL_DATE_C,
        SAME_ACCT_OWNER_AND_UP_ACCT_OWNER_C,
        INQUIRY_SCORE,
        LEAD_SOURCE_C,
        COUNT_OF_NEW_BUSINESS_WON_OPPS_C,
        COUNT_OF_LOST_RENEWAL_OPPORTUNITIES_C,
        ACCOUNT_ZIP_MANUAL_ADMIN_C,
        ZENDESK_ZENDESK_OUTOF_SYNC_C_LEAD,
        INFERRED_COUNTRY,
        NUMBER_OF_OPEN_OPPORTUNITIES_C,
        WON_RENEWAL_OPP_LAST_MONTH_C,
        NAMESPACE,
        ST_PACKAGE_APPETITE_FOR_REPLACEMENT_C,
        UPA_ACCOUNT_TERRITORY_COUNTRY_C,
        BILLING_CITY,
        ZI_COMPANY_PHONE_C,
        TEMP_WEB_STORE_RENEWAL_ISSUE_STATUS_C,
        SUB_INDUSTRY_C,
        ZI_OWNER_C,
        ST_MONITOR_CONTRACT_END_DATE_C,
        MKTO_SI_HIDE_DATE_C,
        DO_YOU_HAVE_A_BUDGET_FOR_THIS_C,
        CONTACT_OWNER_TEAM_C,
        WHERE_ARE_YOU_IN_YOUR_C,
        IMPARTNER_PRM_DATE_ASSIGNED_TO_PARTNER_C,
        FIRST_ORDER_OPPORTUNITY_C,
        WHAT_RELEVANT_PRODUCT_S_WOULD_YOU_C,
        ZENDESK_TAGS_C_LEAD,
        DISCUSS_WHAT_STAGES_OF_DEV_OPS_C,
        DB_WATCH_LIST_CAMPAIGN_CODE_C,
        DB_WATCH_LIST_ACCOUNT_OWNER_C,
        DB_WATCH_LIST_ACCOUNT_TYPE_C,
        PARTNER_CONSENT_C,
        ZI_IT_DEPARTMENT_BUDGET_C,
        CDB_RESP_FOR_GROUP_SAAS_FREE_TIER_C,
        CDB_RESP_FOR_GROUP_SAAS_PREMIUM_TIER_C,
        CDB_RESP_FOR_GROUP_SAA_S_TRIAL_C,
        CDB_IS_GROUP_NAMESPACE_OWNER_C,
        CDB_IS_SELF_MANAGED_ULTIMATE_TIER_C,
        CDB_IND_NAMESPACE_IS_SAA_S_PREMIUM_TIE_C,
        CDB_GROUP_OWNER_OF_SAA_S_FREE_TIER_C,
        CDB_GROUP_MEMBER_OF_SAA_S_FREE_TIER_C,
        CDB_GROUP_MEMBER_OF_SAA_S_BRONZE_TIER_C,
        CDB_GIT_LAB_COM_EMAIL_OPTED_IN_C,
        CDB_IS_SELF_MANAGED_STARTER_TIER_C,
        CDB_GROUP_OWNER_OF_SAA_S_ULTIMATE_TIER_C,
        CDB_GROUP_MEMBER_OF_SAA_S_PREMIUM_TIER_C,
        CDB_IS_INDIVIDUAL_NAMESPACE_OWNER_C,
        CDB_IS_GIT_LAB_COM_USER_C,
        CDB_GROUP_OWNER_OF_SAA_S_PREMIUM_TIER_C,
        CDB_GROUP_OWNER_OF_SAA_S_BRONZE_TIER_C,
        CDB_IS_GROUP_NAMESPACE_MEMBER_C,
        CDB_RESP_FOR_GROUP_SAAS_BRONZE_TIER_C,
        CDB_IS_ZUORA_BILLING_CONTACT_C,
        CDB_IND_NAMESPACE_IS_SAA_S_ULTIMATE_TI_C,
        CDB_IND_NAMESPACE_IS_SAA_S_TRIAL_C,
        CDB_GROUP_MEMBER_OF_SAA_S_ULTIMATE_TIER_C,
        CDB_IS_CUSTOMER_DB_OWNER_C,
        CDB_RESP_FOR_GROUP_SAAS_ULTIMATE_TIER_C,
        CDB_IND_NAMESPACE_IS_SAA_S_FREE_TIER_C,
        CDB_GROUP_OWNER_OF_SAA_S_TRIAL_C,
        CDB_RESPONSIBLE_FOR_FREE_TIER_ONLY_C,
        CDB_IS_SELF_MANAGED_PREMIUM_TIER_C,
        CDB_IS_CUSTOMER_DB_USER_C,
        CDB_GROUP_MEMBER_OF_SAA_S_TRIAL_C,
        CDB_IND_NAMESPACE_IS_SAA_S_BRONZE_TIER_C,
        CDB_IND_NAMESPACE_IS_SAA_S_PREMIUM_TIE_C_CONTACT,
        DO_NOT_EMAIL_REASON,
        CDB_DIM_MARKETING_CONTACT_ID_C,
        CDB_GIT_LAB_COM_ACTIVE_STATE_C,
        CDB_LAST_NAME_C,
        CDB_CUSTOMER_DB_CUSTOMER_ID_C,
        CDB_GIT_LAB_COM_CREATED_DATE_C,
        CDB_CUSTOMER_DB_CONFIRMED_DATE_C,
        CDB_GIT_LAB_COM_CONFIRMED_DATE_C,
        CDB_GIT_LAB_COM_USER_NAME_C,
        CDB_CUSTOMER_DB_CREATED_DATE_C,
        CDB_DAYS_SINCE_SAA_S_TRIAL_ENDED_C,
        CDB_GIT_LAB_COM_LAST_LOGIN_DATE_C,
        CDB_FIRST_NAME_C,
        CDB_ZUORA_CONTACT_ID_C,
        CDB_ZUORA_ACTIVE_STATE_C,
        EMAIL_VERIFICATION_STATUS,
        SETUP_FOR_COMPANY_TEAM_USE_C,
        GACLIENTID_C,
        TSP_DECISION_RATIONALE_C,
        GIT_OPS_SALES_PLAY_C,
        ZI_COMPANY_SIC_CODE_C,
        TEMP_SUBSCRIPTION,
        TEMP_TERM_END_DATE,
        ZI_WEBSITE_C_LEAD,
        ZI_JOB_TITLE_C,
        ZI_FIRST_NAME_C,
        ZI_LAST_NAME_C,
        CRM_PARTNER_ID_C,
        ZI_PHONE_NUMBER_C,
        HEALTH_CHECK_EMPLOYEES_BUCKET_C,
        RING_LEAD_STATUS_C,
        ECIDS,
        KEY_PERSONA_FIRST_ACTION_TIMESTAMP_C,
        KEY_PERSONA_FIRST_ACTION_C,
        WORKED_DATE_C,
        LINKEDIN_SI_COMPANY_PROFILE_C,
        DECISION_MAKER_COUNT_LINKEDIN_C,
        ORDER_TYPE_2_3_OPPS_C,
        IMPARTNER_SYNC_C,
        ZI_SUB_INDUSTRY_C,
        QUALIFICATION_NOTES_C,
        AGGREGATE_DEVELOPER_COUNT_C,
        CDB_COMPANY_NAME_C,
        ZI_FORTUNE_RANKING_C,
        PARTNER_ACCOUNT_CUSTOM_C,
        DOZISF_ZOOM_INFO_NON_MATCHED_REASON_C,
        DOZISF_ZOOM_INFO_ENRICH_STATUS_C,
        PARTER_MISSING_INFO_FOR_CONVERSION_C,
        AVA_AVAAI_HOT_LEAD_C,
        AVA_AVAAI_FURTHER_ACTION_C,
        AVA_AVAAI_LEAD_AT_RISK_C,
        AVA_AVAAI_SMS_OPT_OUT_C,
        AVA_AVAAI_ACTION_REQUIRED_C,
        ZI_SUB_INDUSTRY_C_LEAD,
        VARTOPIA_DRS_PARTNER_ACCOUNT_C,
        CDB_COUNTRY_C,
        AVA_AVAAI_CONVERSICA_LEAD_STATUS_DATE_C,
        AVA_AVAAI_CONVERSICA_LEAD_STATUS_C,
        AVA_AVAAI_CONVERSATION_STAGE_C,
        AVA_AVAAI_LAST_MESSAGE_DATE_C,
        AVA_AVAAI_CONVERSATION_STATUS_DATE_C,
        AVA_AVAAI_CONVERSATION_STAGE_DATE_C,
        AVA_AVAAI_LAST_RESPONSE_DATE_C,
        AVA_AVAAI_HOT_LEAD_DATE_C,
        AVA_AVAAI_DATE_ADDED_C,
        AVA_AVAAI_LEAD_PROFILE_C,
        AVA_AVAAI_CONVERSATION_STATUS_C,
        AVA_AVAAI_FIRST_MESSAGE_DATE_C,
        AVA_AVAAI_DISCOVERED_EMAIL_1_C,
        HOW_MANY_PEOPLE_WILL_BE_EVALUATING_C,
        GROUP_NAMESPACE_ID_C,
        VARTOPIA_DRS_DATE_SHARED_C,
        VARTOPIA_DRS_PARTNER_PROSPECT_ADMIN_EMAIL_NEW_C,
        VARTOPIA_DRS_DATE_ASSIGNED_C,
        VARTOPIA_DRS_DATE_REJECTED_C,
        VARTOPIA_DRS_NUMBER_OF_TIMES_ASSIGNED_C,
        VARTOPIA_DRS_DATE_ACCEPTED_C,
        VARTOPIA_DRS_DATE_RECALLED_C,
        GS_HEALTH_SCM_C,
        GS_HEALTH_OVERALL_PRODUCT_USAGE_C,
        GS_HEALTH_CD_C,
        GS_HEALTH_LICENSE_UTILIZATION_C,
        GS_HEALTH_DEV_SEC_OPS_C,
        AVA_AVAAI_CONFIRMED_PHONE_1_C,
        GS_HEALTH_CI_C,
        PROPOSED_ACCOUNT_OWNER_C,
        PROPOSED_ISR_C,
        LAST_EVENT_PROGRAM_NAME,
        SUB_INDUSTRY_OVERRIDE_C,
        INDUSTRY_OVERRIDE_C,
        AVA_AVAAI_ACTION_REQUIRED_DATE_C,
        AVA_AVAAI_CONFIRMED_PHONE_2_C,
        PARENT_LAM_UPA_AGGREGATE_DEV_COUNT_C,
        AVA_AVAAI_FURTHER_ACTION_DATE_C,
        OUTREACH_ACTIVELY_BEING_SEQUENCED_C,
        EXCLUDE_FROM_ZOOM_INFO_ENRICH_C,
        PREVALENT_TIER_HIERARCHY_C,
        CDB_TIME_SINCE_SAA_S_TRIAL_ENDED_C,
        PQLNAMESPACE_USERS_C,
        PQLNUMBEROFSTAGESACTIVATEDBYNAMESPACE_C,
        PQLSTAGENAMESACTIVATEDBYNAMESPACE_C,
        CDB_TIME_SINCE_SAA_S_TRIAL_OWNER_SIGNUP_C,
        CDB_ZUORA_CREATED_DATE_C,
        CDB_TIME_SINCE_SM_OWNER_TRIAL_SIGN_UP_C,
        ACCOUNT_DEMOGRAPHICS_SALES_SEGMENT_C,
        ACCOUNT_DEMOGRAPHICS_TERRITORY_C_ACCOUNT,
        ACCOUNT_DEMOGRAPHICS_TERRITORY_C,
        ACCOUNT_DEMOGRAPHICS_SALES_SEGMENT_C_ACCOUNT,
        ACCOUNT_DEMOGRAPHICS_REGION_C_ACCOUNT,
        ACCOUNT_DEMOGRAPHICS_REGION_C,
        ACCOUNT_DEMOGRAPHICS_GEO_C,
        ACCOUNT_DEMOGRAPHICS_GEO_C_ACCOUNT,
        VARTOPIA_DRS_PARTNER_PROSPECT_ACCEPTANCE_C,
        ACCOUNT_DEMOGRAPHICS_UPA_STREET_C,
        ACCOUNT_DEMOGRAPHICS_EMPLOYEE_COUNT_C,
        ACCOUNT_DEMOGRAPHICS_UPA_STATE_C,
        LAM_C,
        ACCOUNT_DEMOGRAPHICS_INDUSTRY_C,
        ACCOUNT_DEMOGRAPHICS_AREA_C,
        ACCOUNT_DEMOGRAPHICS_SUB_INDUSTRY_C,
        ACCOUNT_DEMOGRAPHICS_UPA_COUNTRY_C,
        ACCOUNT_DEMOGRAPHICS_MAX_FAMILY_EMPLOYE_C,
        ACCOUNT_DEMOGRAPHICS_LAST_UPDATED_DATE_C,
        ACCOUNT_DEMOGRAPHICS_UPA_POSTAL_CODE_C,
        ACCOUNT_DEMOGRAPHICS_UPA_CITY_C,
        LAM_DEV_COUNT_C,
        BDR_PROSPECTING_STATUS_C,
        MATCHED_ACCOUNT_BDR_PROSPECTING_STATUS_C,
        PQL_NAMESPACE_NAME_C,
        PERSON_LINKEDIN_URL_C,
        RINGLEAD_MERGE_DATE_TIME_C,
        LAST_RINGLEAD_MERGE_DATE_TIME_C,
        DEDICATED_ENGINEERING_C,
        INTEGRATION_SERVICES_C,
        RESTRICTED_ACCOUNT_C,
        VARTOPIA_DRS_FIELDS_UPDATED_ON_C,
        EDUCATION_NEWSLETTER_C,
        VARTOPIA_DRS_VARTOPIA_PARTNER_ACCOUNT_C,
        PQL_NAMESPACE_ID_C,
        PQL_USAGE_PACKET_C,
        LAM_TIER_C,
        BLOCK_MARKETO_SYNC_C,
        LEAD_ACQUISITION_SOURCE_C,
        PTC_SCORE_VALUE_C,
        PTE_SCORE_VALUE_C,
        SALES_TERRITORY_C,
        HIGH_PRIORITY_C,
        UNSUBSCRIBED_REASON_DETAIL,
        MATCHED_ACCOUNT_KEY_ACCOUNT_C,
        SIGNUP_REASON_C,
        HIGH_PRIORITY_TIMESTAMP_C,
        MATCHED_ACCOUNT_LAM_DEV_COUNT_C,
        HIGH_CONVERSION_COHORT_C,
        IMPACTED_BY_USER_LIMIT_C,
        IMPACTED_BY_STORAGE_LIMIT_C,
        IMPACT_STRING_C,
        CDB_GIT_LAB_COM_USER_ID_C,
        CDB_IMPACTED_BY_STORAGE_LIMIT_C,
        PATHFACTORY_LANGUAGE,
        KEY_ACCOUNT_C,
        ACCOUNT_FAMILY_HIGHEST_ZSUB_END_DATE_C,
        USER_C,
        UNKNOWN_ACCOUNT_C,
        CUSTOMER_HEIRARCHY_C,
        ZI_DO_NOT_CALL_MOBILE_PHONE_C,
        ZI_DO_NOT_CALL_DIRECT_PHONE_C,
        CAMPAIGN_NOTES_C,
        PQLNAMESPACECREATORJOBDESCRIPTION_C,
        PQLNAMESOF_INTEGRATIONS_INSTALLED_C,
        PQLNUMBEROF_INTEGRATIONS_INSTALLED_C,
        EMAIL_DOMAIN,
        HIDDEN_DIRECT_PHONE_NUMBER_DNC_C,
        VARTOPIA_DRS_PARTNER_PROSPECT_STATUS_C,
        IS_FIRST_ORDER_PERSON_C,
        PARTNER_MANAGED_C,
        PROSPECT_HEIRARCHY_C,
        FORMER_CUSTOMER_ACCOUNT_C,
        TEAM_OPS_OPT_IN_C,
        CDB_USER_IS_MEMBER_OF_PUBLIC_ULTIMATE_C,
        CDB_USER_IS_MEMBER_OF_PRIVATE_ULTIMATE_C,
        PTPT_PAST_SCORE_GROUP_C,
        PTPT_NAMESPACE_ID_C,
        PTPT_SCORE_DATE_C,
        PTPT_INSIGHTS_C,
        PTPT_SCORE_GROUP_C,
        IMPARTNER_WEB_FORM_C,
        VARTOPIA_DRS_PARTNER_PROSPECT_ADMIN_EMAIL_C,
        VARTOPIA_DRS_VARTOPIA_TRANSACTION_ID_C,
        INELIGIBLE_REASON_C,
        ZOOM_APP_IS_CREATED_BY_ZOOM_APP_C,
        CHANNEL_RECORD_C,
        EMAIL_BOUNCE_CATEGORY,
        EMAIL_BOUNCES,
        EMAIL_BOUNCE_DETAILS,
        EMAIL_BOUNCE_SUBJECT_LANE,
        EMAIL_BOUNCE_DATE_MKTO,
        DELIVERS_AFTER_BOUNCES,
        EMAIL_DELIVERED_AFTER_BOUNCE,
        VARTOPIA_ACCEPTED_DATE_C,
        VARTOPIA_CREATED_DATE_C,
        VARTOPIA_RECALL_DATE_C,
        WORKING_CITY_C,
        WORKING_STATE_C,
        O_N_24_QA,
        O_N_24_SURVEY_QUESTION_4,
        O_N_24_SURVEY_QUESTION_5,
        O_N_24_SURVEY_QUESTION_1,
        O_N_24_SURVEY_QUESTION_2,
        O_N_24_SURVEY_QUESTION_3,
        ON_24_NOTE_UPLOAD_ACTIVATE,
        O_N_24_SURVEY_ANSWER_4,
        O_N_24_SURVEY_ANSWER_5,
        ON_24_POLL_QUESTION_1,
        ON_24_POLL_QUESTION_4,
        O_N_24_SURVEY_ANSWER_1,
        ON_24_POLL_QUESTION_5,
        O_N_24_SURVEY_ANSWER_2,
        ON_24_POLL_QUESTION_2,
        O_N_24_SURVEY_ANSWER_3,
        ON_24_POLL_QUESTION_3,
        ON_24_POLL_COMBINE_3,
        ON_24_POLL_ANSWER_2,
        ON_24_POLL_ANSWER_3,
        ON_24_POLL_ANSWER_4,
        ON_24_POLL_COMBINE_1,
        ON_24_POLL_ANSWER_5,
        ON_24_POLL_COMBINE_2,
        ON_24_POLL_ANSWER_1,
        ON_24_SURVEY_COMBINE_3,
        ON_24_SURVEY_COMBINE_2,
        ON_24_SURVEY_COMBINE_1,
        PARTNER_TYPE_C,
        LAST_LEAD_SOURCE_C,
        SCORE_C,
        LAST_LEAD_SOURCE_DETAILS_C,
        CDB_USER_LIMIT_ENFORCEMENT_DATE_C,
        CDB_USER_LIMIT_NOTIFICATION_DATE_C,
        PREFERRED_LANGUAGE_C,
        ACCOUNT_DEMOGRAPHICS_SALES_SEGMENT_2_C,
        CDB_USER_LIMIT_IMPACTED_NAMESPACE_C,
        PUBSEC_TYPE_C_CONTACT,
        PUBSEC_TYPE_C,
        HIDDEN_MOBILE_PHONE_NUMBER_DNC_C,
        STAMPED_ACCOUNT_DEMO_SEGMENT_C,
        RECORD_SALES_OWNER_EMAIL,
        VARTOPIA_DRS_CLOSED_LOST_REGISTRATIONS_PERCENTAGE_C_CONTACT,
        VARTOPIA_DRS_EXPIRED_REGISTRATIONS_PERCENTAGE_C,
        VARTOPIA_DRS_APPROVED_REGISTRATION_PERCENTAGE_C_CONTACT,
        VARTOPIA_DRS_CLOSED_WON_REGISTRATIONS_PERCENTAGE_C,
        VARTOPIA_DRS_CLOSED_WON_REGISTRATIONS_PERCENTAGE_C_CONTACT,
        VARTOPIA_DRS_APPROVED_REGISTRATION_PERCENTAGE_C,
        VARTOPIA_DRS_CLOSED_LOST_REGISTRATIONS_PERCENTAGE_C,
        VARTOPIA_DRS_DENIED_REGISTRATIONS_PECENTAGE_C,
        VARTOPIA_DRS_DENIED_REGISTRATIONS_PECENTAGE_C_CONTACT,
        VARTOPIA_DRS_EXPIRED_REGISTRATIONS_PERCENTAGE_C_CONTACT,
        UNSUBSCRIBE_ALL_MARKETING,
        COMPANY_ADDRESS_POSTAL_CODE_C,
        COMPANY_ADDRESS_CITY_C,
        COMPANY_ADDRESS_STATE_C,
        COMPANY_ADDRESS_COUNTRY_C,
        COMPANY_ADDRESS_STREET_C,
        ACCOUNT_DEMOGRAPHICS_UPA_STATE_NAME_C,
        PARTNER_RECALLED_C,
        ACCOUNT_DEMOGRAPHICS_UPA_COUNTRY_NAME_C,
        OUTREACH_DATE_ADDED_TO_SEQUENCE_C,
        TRAC_HIER_DOMAIN_C,
        TRAC_HIER_OWNER_C,
        TRAC_HIER_EXCLUDED_FROM_ACCOUNT_HIERARCHIES_C,
        TRAC_HIER_GLOBAL_ULTIMATE_GROUPING_ID_C,
        TRAC_HIER_RE_RUN_TRACTION_HIERARCHIES_C,
        TRAC_HIER_DISABLE_HIERARCHIES_C,
        TRAC_HIER_HIERARCHY_ID_C,
        TRAC_HIER_PARENT_COMPANY_C,
        TRAC_HIER_DUNS_GLOBAL_ULTIMATE_PARENT_C,
        TRAC_RTC_DISABLE_COMPLETE_C,
        TRAC_RTC_RESTORE_TO_ORIGINAL_LEAD_C,
        TRAC_RTC_TIME_DELAY_PROCESSED_C_CONTACT,
        TRAC_RTC_REALTIME_CLEAN_FAILED_C,
        TRAC_RTC_REALTIME_CLEAN_PROCESSED_C,
        TRAC_RTC_DATE_OF_LAST_COMPLETION_C_CONTACT,
        TRAC_RTC_REALTIME_CLEAN_CONTACT_MATCH_C,
        TRAC_RTC_REALTIME_CLEAN_FAILED_C_CONTACT,
        TRAC_RTC_TRACTION_COMPLETE_STATUS_TEXT_C,
        TRAC_RTC_TIME_DELAY_PROCESSED_C,
        TRAC_RTC_TRACTION_COMPLETE_DOMAIN_C_CONTACT,
        TRAC_RTC_WEBSITE_DOMAIN_C,
        TRAC_RTC_TRACTION_COMPLETE_STATUS_C,
        TRAC_RTC_ORIGINAL_COMPLETION_DATE_C_CONTACT,
        TRAC_RTC_REALTIME_CLEAN_COMPANY_MATCH_C,
        TRAC_RTC_RE_RUN_REALTIME_CLEAN_C_CONTACT,
        TRAC_RTC_TRACTION_COMPLETE_DOMAIN_C,
        TRAC_RTC_RE_RUN_REALTIME_CLEAN_C,
        TRAC_RTC_TRACTION_COMPLETE_LEAD_MATCH_C,
        TRAC_RTC_DISABLE_COMPLETE_C_CONTACT,
        TRAC_RTC_TRACTION_COMPLETE_CUSTOM_MATCH_C,
        TRAC_RTC_REALTIME_CLEAN_PROCESSED_C_CONTACT,
        TRAC_RTC_ORIGINAL_LEAD_DATA_C,
        TRAC_RTC_MATCH_TYPE_C,
        TRAC_RTC_REALTIME_CLEAN_ERROR_MESSAGE_C,
        TRAC_RTC_ACCOUNT_C,
        TRAC_RTC_ORIGINAL_COMPLETION_DATE_C,
        TRAC_RTC_DATE_OF_LAST_COMPLETION_C,
        TRAC_RTC_TRACTION_COMPLETE_MATCH_KEY_C,
        TRAC_HIER_PRIMARY_MASTER_ACCOUNT_C,
        TRAC_RTC_REALTIME_CLEAN_ERROR_MESSAGE_C_CONTACT,
        SINGLE_USE_FIELD,
        ENGAGEMENT_MANAGER_C,
        COGNISM_EMAIL_C,
        ZI_EMAIL_C,
        TRAC_HIER_LAST_BUILD_HIERARCHY_DATE_C,
        CANADA_EMAIL_NO_MATCH,
        CANADA_ZI,
        CANADA_ZI_EMAIL_NO_MATCH,
        PTP_PAST_INSIGHTS_C,
        PTP_INSIGHTS_C,
        PTP_SCORE_DATE_C,
        PTP_NAMESPACE_ID_C,
        PTP_SCORE_GROUP_C,
        PTP_PAST_SCORE_GROUP_C,
        ZI_RECORD_PURCHASED_DATE_C,
        PTP_DAYS_SINCE_TRIAL_START_C,
        PHOTOGRAPHY_WAIVER,
        CDB_GROUP_MAINTAINER_OF_SAA_S_PAID_TIER_C,
        DIETARY_ALLERGY_YESNO,
        DIETARY_RESTRICTION_ALLERGY,
        DIETARY_RESTRICTION_DETAIL,
        PHYSICAL_ASSISTANCE_NEEDS,
        EMERGENCY_CONTACT,
        EMERGENCY_CONTACT_PHONE_NUMBER,
        INTEGER_OPEN_FIELD,
        TEXT_AREA_OPEN_FIELD,
        STARTUPS_PROGRAM_STATUS_C,
        DIETARY_RESTRICTIONS_OTHER_2,
        PLANNING_TO_ATTEND_YES_NO,
        SPECIAL_EVENT_INVITE,
        EVENT_DATE_CODE_5,
        PHYSICAL_ASSISTANCE_DETAILS,
        CONTENT_SYNDICATION_ASSET,
        ZI_ULTIMATE_PARENT_ID_C,
        ZI_ULTIMATE_PARENT_NAME_C,
        JOIN_FOR_MAIN_EVENT,
        TRAC_RTC_FIRST_RESPONSE_TIME_IN_SECONDS_C_CONTACT,
        TRAC_RTC_FIRST_RESPONSE_TIME_START_C_CONTACT,
        TRAC_RTC_RESPONSE_TIME_WITHIN_BUSINESS_HOURS_C_CONTACT,
        ZOOM_INFO_ZILIST_TAG,
        CPE_CREDIT,
        IMPARTNER_PRM_PARTNER_ACCOUNT_C,
        INTEGRATE_LEAD_ID,
        VARTOPIA_DRS_ACTIVATE_ACCOUNT_MAPPING_C,
        VARTOPIA_DRS_REJECTION_REASON_C,
        NONPROFITMISSION,
        NONPROFITFOCUSAREA,
        CANADA_EMAIL_CHECK,
        DAYS_SINCE_LAST_ACTIVITY_QUALIFIED_C,
        SHIRT_SIZE_C,
        TRIAL_LICENSE_KEY_2023,
        CDB_DAYS_SINCE_SELF_MANAGED_OWNER_SIGNUP_C,
        PTP_SOURCE_C,
        CDB_DAYS_SINCE_SAA_S_SIGNUP_C,
        MATCHABLE_GENERIC_EMAIL,
        IS_DEFAULTED_TRIAL_C,
        SCORETESTING,
        DEMOGRAPHIC_SCORE_AT_MQL,
        BEHAVIOR_SCORE_AT_MQL,
        TRAC_RTC_TRACTION_COMPLETE_PAUSED_C_CONTACT,
        TRAC_RTC_TRACTION_COMPLETE_PAUSED_C,
        SECURITY_UNSUBSCRIBE,
        G_2_ACTION,
        SAFEBASE_CONTACT_REQUIRED_FOR_ACCOUNT_CREATION_C_CONTACT,
        SAFEBASE_INVITED_C,
        SAFEBASE_NDA_DONE_C,
        SAFEBASE_CONTACT_REQUIRED_FOR_ACCOUNT_CREATION_C,
        SUB_INDUSTRY_ACCT_HIERARCHY_C,
        LAST_CRMPARTNER_ID,
        SUBSCRIBE_COMMUNITY_NEWSLETTER,
        ABM_TIER_C_LEAD,
        SPECIAL_REQUESTS,
        LEAD_SCORE_CLASSIFICATION_C,
        PARTNER_TRIAL,
        GITLAB_HANDLE_BETA,
        GITLAB_PERSONA_BETA,
        GITLAB_PROJECT_ID_BETA,
        GITLAB_PERSONA_2_BETA

    FROM source
    QUALIFY ROW_NUMBER() OVER(PARTITION BY id ORDER BY updated_at DESC) = 1

)

SELECT *
FROM renamed
