WITH source AS (

  SELECT *
  FROM {{ source('zoominfo', 'global') }}

),

renamed AS (

  SELECT
    zi_c_location_id::NUMBER                                             AS location_id,
    zi_c_company_id::INTEGER                                             AS company_id,
    zi_c_is_hq::BOOLEAN                                                  AS is_headquarters,
    zi_es_ecid::NUMBER                                                   AS everstring_company_id,
    zi_c_latitude::FLOAT                                                 AS company_latitude,
    zi_c_longitude::FLOAT                                                AS company_longitude,
    zi_c_verified_address::BOOLEAN                                       AS has_company_verified_address,
    zi_c_employees::NUMBER                                               AS employees,
    zi_c_estimated_age::NUMBER                                           AS estimated_age,
    zi_c_is_b2b::BOOLEAN                                                 AS is_b2b,
    zi_c_is_b2c::BOOLEAN                                                 AS is_b2c,
    zi_es_hq_ecid::NUMBER                                                AS everstring_headquarters_id,
    zi_c_company_latitude::FLOAT                                         AS headquarters_company_latitude,
    zi_c_company_longitude::FLOAT                                        AS headquarters_company_longitude,
    zi_c_company_employees::NUMBER                                       AS headquarters_employees,
    zi_c_alexa_rank::NUMBER                                              AS alexa_rank,
    zi_c_num_keywords::NUMBER                                            AS number_of_keywords,
    zi_c_employee_growth_1yr::FLOAT                                      AS employee_growth_1yr,
    zi_c_employee_growth_2yr::FLOAT                                      AS employee_growth_2yr,
    zi_es_percent_employee_growth::FLOAT                                 AS everstring_percent_employee_growth,
    zi_es_percent_revenue_growth::FLOAT                                  AS everstring_percent_revenue_growth,
    zi_c_name_confidence_score::FLOAT                                    AS company_name_confidence_score,
    zi_c_url_confidence_score::FLOAT                                     AS company_url_confidence_score,
    zi_c_address_confidence_score::FLOAT                                 AS company_address_confidence_score,
    zi_c_phone_confidence_score::FLOAT                                   AS company_phone_confidence_score, 
    zi_c_employees_confidence_score::FLOAT                               AS employees_confidence_score,
    zi_c_revenue_confidence_score::FLOAT                                 AS revenue_confidence_score,
    zi_es_industry_confidence_score::FLOAT                               AS everstring_industry_confidence_score,
    zi_c_naics_confidence_score::FLOAT                                   AS naics_confidence_score,
    zi_c_sic_confidence_score::FLOAT                                     AS sic_confidence_score,
    zi_c_url_last_updated::DATE                                          AS url_last_updated,
    zi_c_inactive_flag::BOOLEAN                                          AS is_inactive,
    zi_c_is_small_business::BOOLEAN                                      AS is_small_business,
    zi_c_is_public::BOOLEAN                                              AS is_public,
    zi_c_has_mobile_app::BOOLEAN                                         AS has_mobile_app,
    zi_c_num_locations::NUMBER                                           AS number_of_locations,
    zi_c_hr_contacts::NUMBER                                             AS number_of_hr_contacts,
    zi_c_sales_contacts::NUMBER                                          AS number_of_sales_contacts,
    zi_c_marketing_contacts::NUMBER                                      AS number_of_marketing_contacts,
    zi_c_finance_contacts::NUMBER                                        AS number_of_finance_contacts,
    zi_c_c_suite_contacts::NUMBER                                        AS number_of_c_suite_contacts,
    zi_c_engineering_contacts::NUMBER                                    AS number_of_engineering_contacts,
    zi_c_it_contacts::NUMBER                                             AS number_of_it_contacts,
    zi_c_operations_contacts::NUMBER                                     AS number_of_operations_contacts,
    zi_c_legal_contacts::NUMBER                                          AS number_of_legal_contacts,
    zi_c_medical_contacts::NUMBER                                        AS number_of_medical_contacts,
    zi_c_latest_funding_age::NUMBER                                      AS latest_funding_age,
    zi_c_num_of_investors::NUMBER                                        AS number_of_investors,
    zi_c_total_funding_amount::NUMBER                                    AS total_funding_amount,
    zi_c_latest_funding_amount::NUMBER                                   AS latest_funding_amount,
    zi_c_num_funding_rounds::NUMBER                                      AS number_of_funding_rounds,
    zi_c_is_fortune_100::BOOLEAN                                         AS is_fortune_100,
    zi_c_is_fortune_500::BOOLEAN                                         AS is_fortune_500,
    zi_c_is_s_and_p_500::BOOLEAN                                         AS is_s_and_p_500,
    zi_c_is_domestic_hq::BOOLEAN                                         AS is_domestic_hq,
    zi_c_is_ultimate_parent::BOOLEAN                                     AS is_ultimate_parent,
    zi_c_is_subsidiary::BOOLEAN                                          AS is_subsidiary,
    zi_c_is_franchisor::BOOLEAN                                          AS is_franchisor,
    zi_c_is_franchisee::BOOLEAN                                          AS is_franchisee,
    zi_c_is_immediate_parent::BOOLEAN                                    AS is_immediate_parent,
    zi_c_is_domestic_parent::BOOLEAN                                     AS is_domestic_parent,
    zi_c_hierarchy_level::NUMBER                                         AS hierarchy_level,
    zi_c_parent_child_confidence_score::FLOAT                            AS parent_child_confidence_score,
    zi_c_immediate_parent_company_id::NUMBER                             AS immediate_parent_company_id,
    zi_es_immediate_parent_ecid::NUMBER                                  AS everstring_immediate_parent_id,
    zi_c_domestic_parent_company_id::NUMBER                              AS domestic_parent_company_id, 
    zi_es_domestic_parent_ecid::NUMBER                                   AS everstring_domestic_parent_id,
    zi_c_ultimate_parent_company_id::NUMBER                              AS ultimate_parent_company_id,
    zi_es_ultimate_parent_ecid::NUMBER                                   AS everstring_ultimate_parent_id,
    zi_c_franchisor_company_id::NUMBER                                   AS franchisor_company_id,
    zi_es_franchisor_ecid::NUMBER                                        AS everstring_franchisor_id,
    zi_c_last_updated_date::DATE                                         AS last_updated_date,
    NULLIF(zi_es_location_id::VARCHAR, '')                               AS everstring_location_id,
    NULLIF(zi_c_tier_grade::VARCHAR, '')                                 AS tier_grade,
    NULLIF(zi_c_name::VARCHAR, '')                                       AS location_name,
    NULLIF(zi_c_name_display::VARCHAR, '')                               AS colloquial_name,
    NULLIF(zi_c_legal_entity_type::VARCHAR, '')                          AS legal_entity_type,
    NULLIF(zi_c_url::VARCHAR, '')                                        AS company_url,
    NULLIF(zi_c_street::VARCHAR, '')                                     AS company_street,
    NULLIF(zi_c_street_2::VARCHAR, '')                                   AS company_street_2,
    NULLIF(zi_c_city::VARCHAR, '')                                       AS company_city,
    NULLIF(zi_c_state::VARCHAR, '')                                      AS company_state,
    NULLIF(zi_c_zip::VARCHAR, '')                                        AS company_zip,
    NULLIF(zi_c_country::VARCHAR, '')                                    AS company_country,
    NULLIF(zi_c_cbsa_name::VARCHAR, '')                                  AS cbsa_name,
    NULLIF(zi_c_county::VARCHAR, '')                                     AS company_county,
    NULLIF(zi_c_employee_range::VARCHAR, '')                             AS employee_range,
    NULLIF(zi_c_revenue_range::VARCHAR, '')                              AS revenue_range,
    zi_c_revenue::NUMBER * 1000                                          AS revenue, -- convert from thousand
    NULLIF(zi_c_phone::VARCHAR, '')                                      AS company_phone,
    NULLIF(zi_c_fax::VARCHAR, '')                                        AS company_fax,
    NULLIF(zi_c_industry_primary::VARCHAR, '')                           AS industry_primary,
    NULLIF(zi_c_sub_industry_primary::VARCHAR, '')                       AS sub_industry_primary,
    NULLIF(zi_c_industries::VARCHAR, '')                                 AS industries,
    NULLIF(zi_c_sub_industries::VARCHAR, '')                             AS sub_industries,
    NULLIF(zi_es_industry::VARCHAR, '')                                  AS everstring_industry,
    NULLIF(zi_es_industries_top3::VARCHAR, '')                           AS everstring_industries_top3,
    NULLIF(zi_c_naics2::VARCHAR, '')                                     AS naics_2_code,
    NULLIF(zi_c_naics4::VARCHAR, '')                                     AS naics_4_code,
    NULLIF(zi_c_naics6::VARCHAR, '')                                     AS naics_6_code,
    NULLIF(zi_c_naics_top3::VARCHAR, '')                                 AS naics_top3,
    NULLIF(zi_c_sic2::VARCHAR, '')                                       AS sic_2_code,
    NULLIF(zi_c_sic3::VARCHAR, '')                                       AS sic_3_code,
    NULLIF(zi_c_sic4::VARCHAR, '')                                       AS sic_4_code,
    NULLIF(zi_c_sic_top3::VARCHAR, '')                                   AS sic_top3,
    NULLIF(zi_c_year_founded::VARCHAR, '')                               AS year_founded,
    NULLIF(zi_es_hq_location_id::VARCHAR, '')                            AS everstring_headquarters_location_id,
    NULLIF(zi_c_company_name::VARCHAR, '')                               AS headquarters_company_name,
    NULLIF(zi_c_company_url::VARCHAR, '')                                AS headquarters_company_url,
    NULLIF(zi_c_company_street::VARCHAR, '')                             AS headquarters_company_street,
    NULLIF(zi_c_company_street_2::VARCHAR, '')                           AS headquarters_company_street_2,
    NULLIF(zi_c_company_city::VARCHAR, '')                               AS headquarters_company_city,
    NULLIF(zi_c_company_state::VARCHAR, '')                              AS headquarters_company_state,
    NULLIF(zi_c_company_zip::VARCHAR, '')                                AS headquarters_company_zip,
    NULLIF(zi_c_company_country::VARCHAR, '')                            AS headquarters_company_country,
    NULLIF(zi_c_company_cbsa_name::VARCHAR, '')                          AS headquarters_company_cbsa_name,
    NULLIF(zi_c_company_county::VARCHAR, '')                             AS headquarters_company_county,
    NULLIF(zi_c_company_verified_address, '')::BOOLEAN                   AS has_headquarters_company_verified_address,
    NULLIF(zi_c_company_employee_range::VARCHAR, '')                     AS headquarters_employee_range,
    NULLIF(zi_c_company_revenue_range::VARCHAR, '')                      AS headquarters_revenue_range,
    zi_c_company_revenue::NUMBER * 1000                                  AS headquarters_revenue, -- convert from thousand
    NULLIF(zi_c_company_phone::VARCHAR, '')                              AS headquarters_company_phone,
    NULLIF(zi_c_company_fax::VARCHAR, '')                                AS headquarters_company_fax,
    NULLIF(zi_c_linkedin_url::VARCHAR, '')                               AS linkedin_url,
    NULLIF(zi_c_facebook_url::VARCHAR, '')                               AS facebook_url,
    NULLIF(zi_c_twitter_url::VARCHAR, '')                                AS twitter_url,
    NULLIF(zi_c_yelp_url::VARCHAR, '')                                   AS yelp_url,
    NULLIF(zi_c_keywords::VARCHAR, '')                                   AS company_keywords,
    NULLIF(zi_c_top_keywords::VARCHAR, '')                               AS top_keywords,
    NULLIF(zi_es_growth::VARCHAR, '')                                    AS everstring_growth,
    NULLIF(zi_es_employee_growth::VARCHAR, '')                           AS everstring_employee_growth,
    NULLIF(zi_es_revenue_growth::VARCHAR, '')                            AS everstring_revenue_growth,
    NULLIF(zi_es_industries_top3_confidence_scores::VARCHAR, '')         AS everstring_industries_top3_confidence_scores,
    NULLIF(zi_c_naics_top3_confidence_scores::VARCHAR, '')               AS naics_top3_confidence_scores,
    NULLIF(zi_c_sic_top3_confidence_scores::VARCHAR, '')                 AS sic_top3_confidence_scores,
    NULLIF(TRIM(zi_c_ids_merged::VARCHAR,'|'),'')                        AS merged_previous_company_ids,
    NULLIF(zi_c_names_other::VARCHAR, '')                                AS other_company_names,
    NULLIF(zi_c_url_status::VARCHAR, '')                                 AS company_url_status,
    NULLIF(zi_c_urls_alt::VARCHAR, '')                                   AS alternate_company_urls,
    NULLIF(zi_c_ein::VARCHAR, '')                                        AS company_ein,
    NULLIF(zi_c_ticker::VARCHAR, '')                                     AS company_ticker,
    NULLIF(zi_c_tickers_alt::VARCHAR, '')                                AS alternate_company_tickers,
    NULLIF(zi_c_currency_code::VARCHAR, '')                              AS currency_code,
    NULLIF(zi_c_tech_ids::VARCHAR, '')                                   AS tech_ids,
    NULLIF(zi_c_investor_names::VARCHAR, '')                             AS investor_names,
    NULLIF(zi_c_funding_strength::VARCHAR, '')                           AS funding_strength,
    NULLIF(zi_c_funding_type::VARCHAR, '')                               AS funding_type,
    NULLIF(zi_c_latest_funding_date, '')::DATE                           AS latest_funding_date,
    NULLIF(zi_c_hierarchy_code::VARCHAR, '')                             AS hierarchy_code,
    NULLIF(zi_es_immediate_parent_location_id::VARCHAR, '')              AS everstring_immediate_parent_location_id,
    NULLIF(zi_c_immediate_parent_name::VARCHAR, '')                      AS immediate_parent_name,
    NULLIF(zi_c_immediate_parent_url::VARCHAR, '')                       AS immediate_parent_url,
    NULLIF(zi_c_immediate_parent_street::VARCHAR, '')                    AS immediate_parent_street,
    NULLIF(zi_c_immediate_parent_street_2::VARCHAR, '')                  AS immediate_parent_street_2,
    NULLIF(zi_c_immediate_parent_city::VARCHAR, '')                      AS immediate_parent_city,
    NULLIF(zi_c_immediate_parent_zip::VARCHAR, '')                       AS immediate_parent_zip,
    NULLIF(zi_c_immediate_parent_state::VARCHAR, '')                     AS immediate_parent_state,
    NULLIF(zi_c_immediate_parent_country::VARCHAR, '')                   AS immediate_parent_country,
    NULLIF(zi_es_domestic_parent_location_id::VARCHAR, '')               AS everstring_domestic_parent_location_id,
    NULLIF(zi_c_domestic_parent_name::VARCHAR, '')                       AS domestic_parent_name,
    NULLIF(zi_c_domestic_parent_url::VARCHAR, '')                        AS domestic_parent_url,
    NULLIF(zi_c_domestic_parent_street::VARCHAR, '')                     AS domestic_parent_street,
    NULLIF(zi_c_domestic_parent_street_2::VARCHAR, '')                   AS domestic_parent_street_2,
    NULLIF(zi_c_domestic_parent_city::VARCHAR, '')                       AS domestic_parent_city,
    NULLIF(zi_c_domestic_parent_zip::VARCHAR, '')                        AS domestic_parent_zip,
    NULLIF(zi_c_domestic_parent_state::VARCHAR, '')                      AS domestic_parent_state,
    NULLIF(zi_c_domestic_parent_country::VARCHAR, '')                    AS domestic_parent_country,
    NULLIF(zi_c_domestic_parent_location_id::VARCHAR, '')                AS domestic_parent_location_id,
    NULLIF(zi_es_ultimate_parent_location_id::VARCHAR, '')               AS everstring_ultimate_parent_location_id,
    NULLIF(zi_c_ultimate_parent_name::VARCHAR, '')                       AS ultimate_parent_name,
    NULLIF(zi_c_ultimate_parent_url::VARCHAR, '')                        AS ultimate_parent_url,
    NULLIF(zi_c_ultimate_parent_street::VARCHAR, '')                     AS ultimate_parent_street,
    NULLIF(zi_c_ultimate_parent_street_2::VARCHAR, '')                   AS ultimate_parent_street_2,
    NULLIF(zi_c_ultimate_parent_city::VARCHAR, '')                       AS ultimate_parent_city,
    NULLIF(zi_c_ultimate_parent_zip::VARCHAR, '')                        AS ultimate_parent_zip,
    NULLIF(zi_c_ultimate_parent_state::VARCHAR, '')                      AS ultimate_parent_state,
    NULLIF(zi_c_ultimate_parent_country::VARCHAR, '')                    AS ultimate_parent_country,
    NULLIF(zi_es_franchisor_location_id::VARCHAR, '')                    AS everstring_franchisor_location_id,
    NULLIF(zi_c_franchisor_name::VARCHAR, '')                            AS franchisor_name,
    NULLIF(zi_c_franchisor_url::VARCHAR, '')                             AS franchisor_url,
    NULLIF(zi_c_franchisor_street::VARCHAR, '')                          AS franchisor_street,
    NULLIF(zi_c_franchisor_street_2::VARCHAR, '')                        AS franchisor_street_2,
    NULLIF(zi_c_franchisor_city::VARCHAR, '')                            AS franchisor_city,
    NULLIF(zi_c_franchisor_zip::VARCHAR, '')                             AS franchisor_zip,
    NULLIF(zi_c_franchisor_state::VARCHAR, '')                           AS franchisor_state,
    NULLIF(zi_c_franchisor_country::VARCHAR, '')                         AS franchisor_country,
    TO_DATE(zi_c_release_date, 'YYYYMM')::DATE                           AS release_date
  FROM source

)

SELECT *
FROM renamed
