WITH zuora_revenue_revenue_contract_header AS (

    SELECT *
    FROM {{source('zuora_revenue','zuora_revenue_revenue_contract_header')}}
    QUALIFY RANK() OVER (PARTITION BY id ORDER BY incr_updt_dt DESC) = 1

), renamed AS (

    SELECT 

      id::VARCHAR                                   AS revenue_contract_id,
      version::VARCHAR                              AS revenue_contract_version,
      batch_id::VARCHAR                             AS revenue_contract_batch_id,
      book_id::VARCHAR                              AS book_id,
      list_amt::FLOAT                               AS list_amount,
      sell_amt::FLOAT                               AS sell_amount,
      ca_amt::FLOAT                                 AS contract_asset_amount,
      cl_amt::FLOAT                                 AS contract_liability_amount,
      tot_cv_amt::FLOAT                             AS carve_amount,
      tmpl_id::VARCHAR                              AS template_id,
      fv_date::DATETIME                             AS fair_value_date,
      curr::VARCHAR                                 AS transactional_currency,
      f_cur::VARCHAR                                AS functional_currency,
      f_ex_rate::VARCHAR                            AS functional_currency_exchange_rate,
      g_ex_rate::VARCHAR                            AS reporting_currency_exchange_rate,
      atr1::VARCHAR                                 AS revenue_contract_attribute_1,
      atr2::VARCHAR                                 AS revenue_contract_attribute_2,
      atr3::VARCHAR                                 AS revenue_contract_attribute_3,
      atr4::VARCHAR                                 AS revenue_contract_attribute_4,
      atr5::VARCHAR                                 AS revenue_contract_attribute_5,
      company_code::VARCHAR                         AS company_code,
      init_pob_exp_dt::DATETIME                     AS initial_performance_obligation_expiration_date,
      cstmr_nm::VARCHAR                             AS customer_name,
      posted_flag::VARCHAR                          AS is_posted,
      alloc_error_flag::VARCHAR                     AS is_allocation_error,
      multi_curr_flag::VARCHAR                      AS is_multiple_currency,
      alloc_eligible_flag::VARCHAR                  AS is_allocation_eligible,
      manual_cv_flag::VARCHAR                       AS is_manual_cv,
      manual_rc_flag::VARCHAR                       AS is_manual_revenue_contract,
      freeze_flag::VARCHAR                          AS is_freeze,
      approval_status_flag::VARCHAR                 AS revnue_contract_approval_status,
      conversion_flag::VARCHAR                      AS is_conversion,
      archive_flag::VARCHAR                         AS is_archive,
      stale_group_flag::VARCHAR                     AS is_stale_group,
      initial_alloc_flag::VARCHAR                   AS is_initial_allocation,
      alloc_trtmt_flag::VARCHAR                     AS revenue_contract_allocation_treatment,
      schd_hold_flag::VARCHAR                       AS is_schedule_hold,
      revrev_hold_flag::VARCHAR                     AS is_revrev_hold,
      alloc_schd_hold_flag::VARCHAR                 AS is_allocation_schedule_hold,
      alloc_rec_hold_flag::VARCHAR                  AS is_allocation_recognition_hold,
      mje_rc_flag::VARCHAR                          AS is_manual_journal_entry_revenue_contract,
      netting_pending_flag::VARCHAR                 AS is_netting_pending,
      is_hold_applied_flag::VARCHAR                 AS is_hold_applied,
      CONCAT(crtd_prd_id::VARCHAR, '01')            AS revenue_contract_created_period_id,
      client_id::VARCHAR                            AS client_id,
      sec_atr_val::VARCHAR                          AS security_attribute_value,
      crtd_by::VARCHAR                              AS revenue_contract_created_by,
      crtd_dt::DATETIME                             AS revenue_contract_created_date,
      updt_by::VARCHAR                              AS revenue_contract_updated_by,
      updt_dt::DATETIME                             AS revenue_contract_updated_date,
      incr_updt_dt::DATETIME                        AS incremental_update_date,
      ct_mod_end_dt::DATETIME                       AS revenue_contract_modification_end_date,
      is_allocatable_flag::VARCHAR                  AS is_allocatable,
      inter_company_flag::VARCHAR                   AS is_inter_company,
      rc_crtd_manual_flag::VARCHAR                  AS is_revenue_contract_manually_created,
      rc_ssp_pct::VARCHAR                           AS revenue_contract_ssp_percent,
      multi_f_curr_flag::VARCHAR                    AS is_multi_functional_currency,
      skip_allocation_flag::VARCHAR                 AS is_skip_allocation,
      vc_allocation_flag::VARCHAR                   AS is_variable_consideration_allocation,
      rc_closed_flag::VARCHAR                       AS is_revenue_contract_closed,
      CONCAT(timeline_period_flag::VARCHAR, '01')   AS timeline_period,
      new_rc_by_ctmod_flag::VARCHAR                 AS is_new_revenue_contact_created_by_ct_mod,
      manual_hold_flag::VARCHAR                     AS is_manual_hold,
      acct_updt_dt::DATETIME                        AS account_updated_date,
      multi_t_curr_flag::VARCHAR                    AS is_multiple_transactional_currency,
      retro_pros_flag::VARCHAR                      AS is_retro_pros,
      exception_flag::VARCHAR                       AS is_exception,
      rev_rel_appr_flag::VARCHAR                    AS is_rev_rel_approval,
      CONCAT(max_schd_prd::VARCHAR, '01')           AS max_schedule_period,
      lifecycle_change_dt::DATETIME                 AS lifecycle_change_date,
      old_ct_mod_end_dt::DATETIME                   AS old_revenue_contract_modification_end_date,
      lifecycle_state_flag::VARCHAR                 AS lifecycle_state,
      skip_ctmod_flag::VARCHAR                      AS is_skip_revenue_contract_modification,
      hybrid_rc_flag::VARCHAR                       AS is_hybrid_revenue_contract,
      get_delink_flag::VARCHAR                      AS is_delinked,
      ltst_mje_flag::VARCHAR                        AS is_lt_st_manual_journal_entry,
      alloc_multi_curr_flag::VARCHAR                AS is_multiple_currency_allocation,
      alloc_multi_f_curr_flag::VARCHAR              AS is_multiple_functional_currency_allocation,
      alloc_multi_t_curr_flag::VARCHAR              AS is_multiple_transactional_currency_allocation
      
    FROM zuora_revenue_revenue_contract_header

)

SELECT *
FROM renamed 